# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nexthop.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import networktypes_pb2 as networktypes__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rnexthop.proto\x12\x1eopi_api.network.cloud.v1alpha1\x1a\x12networktypes.proto\x1a\x19google/api/resource.proto\"\xe6\x01\n\x07NextHop\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12?\n\x04spec\x18\x02 \x01(\x0b\x32+.opi_api.network.cloud.v1alpha1.NextHopSpecR\x04spec\x12\x45\n\x06status\x18\x03 \x01(\x0b\x32-.opi_api.network.cloud.v1alpha1.NextHopStatusR\x06status:?\xea\x41<\n&opi_api.network.cloud.v1alpha1/nexthop\x12\x12nexthops/{nexthop}\"\xa5\x02\n\x0bNextHopSpec\x12\\\n\x0foverlay_nh_info\x18\x01 \x01(\x0b\x32\x32.opi_api.network.cloud.v1alpha1.OverlayNextHopSpecH\x00R\roverlayNhInfo\x12_\n\x10underlay_nh_info\x18\x02 \x01(\x0b\x32\x33.opi_api.network.cloud.v1alpha1.UnderlayNextHopSpecH\x00R\x0eunderlayNhInfo\x12M\n\nip_nh_info\x18\x03 \x01(\x0b\x32-.opi_api.network.cloud.v1alpha1.IPNextHopSpecH\x00R\x08ipNhInfoB\x08\n\x06nhinfo\"k\n\x13UnderlayNextHopSpec\x12,\n\x12interface_name_ref\x18\x01 \x01(\tR\x10interfaceNameRef\x12&\n\x0funderlay_nh_mac\x18\x02 \x01(\x0cR\runderlayNhMac\"<\n\x12OverlayNextHopSpec\x12&\n\x0ftunnel_name_ref\x18\x01 \x01(\tR\rtunnelNameRef\"\xa8\x01\n\rIPNextHopSpec\x12 \n\x0cvpc_name_ref\x18\x01 \x01(\tR\nvpcNameRef\x12O\n\nip_address\x18\x02 \x01(\x0b\x32\x30.opi_api.network.opinetcommon.v1alpha1.IPAddressR\tipAddress\x12\x12\n\x04vlan\x18\x03 \x01(\x05R\x04vlan\x12\x10\n\x03mac\x18\x04 \x01(\x0cR\x03mac\"\xaa\x02\n\rNextHopStatus\x12L\n\thw_handle\x18\x01 \x01(\x0b\x32/.opi_api.network.opinetcommon.v1alpha1.HwHandleR\x08hwHandle\x12\x61\n\x10underlay_nh_info\x18\x02 \x01(\x0b\x32\x35.opi_api.network.cloud.v1alpha1.UnderlayNextHopStatusH\x00R\x0eunderlayNhInfo\x12^\n\x0foverlay_nh_info\x18\x03 \x01(\x0b\x32\x34.opi_api.network.cloud.v1alpha1.OverlayNextHopStatusH\x00R\roverlayNhInfoB\x08\n\x06nhinfo\"?\n\x15UnderlayNextHopStatus\x12\x12\n\x04port\x18\x01 \x01(\x05R\x04port\x12\x12\n\x04vlan\x18\x02 \x01(\x05R\x04vlan\"e\n\x14OverlayNextHopStatus\x12M\n\ttunnel_ip\x18\x01 \x01(\x0b\x32\x30.opi_api.network.opinetcommon.v1alpha1.IPAddressR\x08tunnelIp\"\x7f\n\rNextHopLookup\x12\x41\n\x04type\x18\x01 \x01(\x0e\x32+.opi_api.network.cloud.v1alpha1.NextHopTypeH\x00R\x04type\x12 \n\x0bnh_name_ref\x18\x02 \x01(\tH\x00R\tnhNameRefB\t\n\x07gettype\"\x84\x02\n\x0cNextHopGroup\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x44\n\x04spec\x18\x02 \x01(\x0b\x32\x30.opi_api.network.cloud.v1alpha1.NextHopGroupSpecR\x04spec\x12J\n\x06status\x18\x03 \x01(\x0b\x32\x32.opi_api.network.cloud.v1alpha1.NextHopGroupStatusR\x06status:N\xea\x41K\n+opi_api.network.cloud.v1alpha1/nexthopgroup\x12\x1cnexthopgroups/{nexthopgroup}\"\x9f\x01\n\x10NextHopGroupSpec\x12\x44\n\x04type\x18\x01 \x01(\x0e\x32\x30.opi_api.network.cloud.v1alpha1.NextHopGroupTypeR\x04type\x12\x45\n\x07members\x18\x02 \x03(\x0b\x32+.opi_api.network.cloud.v1alpha1.NextHopSpecR\x07members\"\xab\x01\n\x12NextHopGroupStatus\x12G\n\x07members\x18\x01 \x03(\x0b\x32-.opi_api.network.cloud.v1alpha1.NextHopStatusR\x07members\x12L\n\thw_handle\x18\x02 \x01(\x0b\x32/.opi_api.network.opinetcommon.v1alpha1.HwHandleR\x08hwHandle\"\x94\x01\n\x12NextHopGroupLookup\x12\x46\n\x04type\x18\x01 \x01(\x0e\x32\x30.opi_api.network.cloud.v1alpha1.NextHopGroupTypeH\x00R\x04type\x12+\n\x11nh_group_name_ref\x18\x02 \x01(\tH\x00R\x0enhGroupNameRefB\t\n\x07gettype*y\n\x0bNextHopType\x12\x1d\n\x19NEXT_HOP_TYPE_UNSPECIFIED\x10\x00\x12\x14\n\x10NEXT_HOP_TYPE_IP\x10\x01\x12\x1a\n\x16NEXT_HOP_TYPE_UNDERLAY\x10\x02\x12\x19\n\x15NEXT_HOP_TYPE_OVERLAY\x10\x03*\x84\x01\n\x10NextHopGroupType\x12#\n\x1fNEXT_HOP_GROUP_TYPE_UNSPECIFIED\x10\x00\x12$\n NEXT_HOP_GROUP_TYPE_OVERLAY_ECMP\x10\x01\x12%\n!NEXT_HOP_GROUP_TYPE_UNDERLAY_ECMP\x10\x02\x42m\n\x1eopi_api.network.cloud.v1alpha1B\x0cNextHopProtoP\x01Z;github.com/opiproject/opi-api/network/cloud/v1alpha1/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nexthop_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036opi_api.network.cloud.v1alpha1B\014NextHopProtoP\001Z;github.com/opiproject/opi-api/network/cloud/v1alpha1/gen/go'
  _globals['_NEXTHOP']._options = None
  _globals['_NEXTHOP']._serialized_options = b'\352A<\n&opi_api.network.cloud.v1alpha1/nexthop\022\022nexthops/{nexthop}'
  _globals['_NEXTHOPGROUP']._options = None
  _globals['_NEXTHOPGROUP']._serialized_options = b'\352AK\n+opi_api.network.cloud.v1alpha1/nexthopgroup\022\034nexthopgroups/{nexthopgroup}'
  _globals['_NEXTHOPTYPE']._serialized_start=2315
  _globals['_NEXTHOPTYPE']._serialized_end=2436
  _globals['_NEXTHOPGROUPTYPE']._serialized_start=2439
  _globals['_NEXTHOPGROUPTYPE']._serialized_end=2571
  _globals['_NEXTHOP']._serialized_start=97
  _globals['_NEXTHOP']._serialized_end=327
  _globals['_NEXTHOPSPEC']._serialized_start=330
  _globals['_NEXTHOPSPEC']._serialized_end=623
  _globals['_UNDERLAYNEXTHOPSPEC']._serialized_start=625
  _globals['_UNDERLAYNEXTHOPSPEC']._serialized_end=732
  _globals['_OVERLAYNEXTHOPSPEC']._serialized_start=734
  _globals['_OVERLAYNEXTHOPSPEC']._serialized_end=794
  _globals['_IPNEXTHOPSPEC']._serialized_start=797
  _globals['_IPNEXTHOPSPEC']._serialized_end=965
  _globals['_NEXTHOPSTATUS']._serialized_start=968
  _globals['_NEXTHOPSTATUS']._serialized_end=1266
  _globals['_UNDERLAYNEXTHOPSTATUS']._serialized_start=1268
  _globals['_UNDERLAYNEXTHOPSTATUS']._serialized_end=1331
  _globals['_OVERLAYNEXTHOPSTATUS']._serialized_start=1333
  _globals['_OVERLAYNEXTHOPSTATUS']._serialized_end=1434
  _globals['_NEXTHOPLOOKUP']._serialized_start=1436
  _globals['_NEXTHOPLOOKUP']._serialized_end=1563
  _globals['_NEXTHOPGROUP']._serialized_start=1566
  _globals['_NEXTHOPGROUP']._serialized_end=1826
  _globals['_NEXTHOPGROUPSPEC']._serialized_start=1829
  _globals['_NEXTHOPGROUPSPEC']._serialized_end=1988
  _globals['_NEXTHOPGROUPSTATUS']._serialized_start=1991
  _globals['_NEXTHOPGROUPSTATUS']._serialized_end=2162
  _globals['_NEXTHOPGROUPLOOKUP']._serialized_start=2165
  _globals['_NEXTHOPGROUPLOOKUP']._serialized_end=2313
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: networkpolicy.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import networktypes_pb2 as networktypes__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13networkpolicy.proto\x12\x1eopi_api.network.cloud.v1alpha1\x1a\x12networktypes.proto\x1a\x19google/api/resource.proto\"\x90\x02\n\x0eSecurityPolicy\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x46\n\x04spec\x18\x02 \x01(\x0b\x32\x32.opi_api.network.cloud.v1alpha1.SecurityPolicySpecR\x04spec\x12L\n\x06status\x18\x03 \x01(\x0b\x32\x34.opi_api.network.cloud.v1alpha1.SecurityPolicyStatusR\x06status:T\xea\x41Q\n-opi_api.network.cloud.v1alpha1/securitypolicy\x12 securitypolicys/{securitypolicy}\"\xdc\x03\n\x12SecurityPolicySpec\x12\x46\n\x04type\x18\x01 \x01(\x0e\x32\x32.opi_api.network.cloud.v1alpha1.SecurityPolicyTypeR\x04type\x12R\n\x0e\x61\x64\x64ress_family\x18\x02 \x01(\x0e\x32+.opi_api.network.opinetcommon.v1alpha1.IpAfR\raddressFamily\x12\x1c\n\tstateless\x18\x03 \x01(\x08R\tstateless\x12q\n\x17\x64\x65\x66\x61ult_security_action\x18\x04 \x01(\x0e\x32\x39.opi_api.network.opinetcommon.v1alpha1.SecurityRuleActionR\x15\x64\x65\x66\x61ultSecurityAction\x12\x46\n\x05rules\x18\x05 \x03(\x0b\x32\x30.opi_api.network.cloud.v1alpha1.SecurityRuleInfoR\x05rules\x12Q\n\x0brule_format\x18\x06 \x01(\x0e\x32\x30.opi_api.network.cloud.v1alpha1.PolicyRuleFormatR\nruleFormat\"x\n\x10SecurityRuleInfo\x12\x1b\n\trule_name\x18\x01 \x01(\tR\x08ruleName\x12G\n\x05\x61ttrs\x18\x02 \x01(\x0b\x32\x31.opi_api.network.cloud.v1alpha1.SecurityRuleAttrsR\x05\x61ttrs\"\xb0\x02\n\x11SecurityRuleAttrs\x12\x1a\n\x08priority\x18\x01 \x01(\x05R\x08priority\x12\x46\n\x05match\x18\x02 \x01(\x0b\x32\x30.opi_api.network.opinetcommon.v1alpha1.RuleMatchR\x05match\x12Q\n\x06\x61\x63tion\x18\x03 \x01(\x0e\x32\x39.opi_api.network.opinetcommon.v1alpha1.SecurityRuleActionR\x06\x61\x63tion\x12 \n\x0bterminating\x18\x04 \x01(\x08R\x0bterminating\x12\x42\n\x08\x61lg_spec\x18\x05 \x01(\x0b\x32\'.opi_api.network.cloud.v1alpha1.ALGSpecR\x07\x61lgSpec\"8\n\nFTPOptions\x12*\n\x11\x61llow_ip_mismatch\x18\x01 \x01(\x08R\x0f\x61llowIpMismatch\"\xce\x02\n\nDNSOptions\x12\x39\n\x19\x64rop_multi_query_messages\x18\x01 \x01(\x08R\x16\x64ropMultiQueryMessages\x12:\n\x1a\x64rop_large_domain_name_ref\x18\x02 \x01(\x08R\x16\x64ropLargeDomainNameRef\x12\x37\n\x18\x64rop_long_label_messages\x18\x03 \x01(\x08R\x15\x64ropLongLabelMessages\x12\x37\n\x18\x64rop_multi_zone_messages\x18\x04 \x01(\x08R\x15\x64ropMultiZoneMessages\x12)\n\x10response_timeout\x18\x05 \x01(\x05R\x0fresponseTimeout\x12,\n\x12max_message_length\x18\x06 \x01(\x05R\x10maxMessageLength\"-\n\x0cMSRPCOptions\x12\x1d\n\nprogram_id\x18\x01 \x03(\x0cR\tprogramId\".\n\rSunRPCOptions\x12\x1d\n\nprogram_id\x18\x01 \x03(\x0cR\tprogramId\"\xca\x03\n\x07\x41LGSpec\x12\x42\n\x08\x61lg_type\x18\x01 \x01(\x0e\x32\'.opi_api.network.cloud.v1alpha1.ALGTypeR\x07\x61lgType\x12!\n\x0cidle_timeout\x18\x02 \x01(\x05R\x0bidleTimeout\x12M\n\x0b\x66tp_options\x18\x03 \x01(\x0b\x32*.opi_api.network.cloud.v1alpha1.FTPOptionsH\x00R\nftpOptions\x12M\n\x0b\x64ns_options\x18\x04 \x01(\x0b\x32*.opi_api.network.cloud.v1alpha1.DNSOptionsH\x00R\ndnsOptions\x12S\n\rmsrpc_options\x18\x05 \x01(\x0b\x32,.opi_api.network.cloud.v1alpha1.MSRPCOptionsH\x00R\x0cmsrpcOptions\x12V\n\x0esunrpc_options\x18\x06 \x01(\x0b\x32-.opi_api.network.cloud.v1alpha1.SunRPCOptionsH\x00R\rsunrpcOptionsB\r\n\x0b\x61lg_options\"\xe9\x02\n\x14SecurityPolicyStatus\x12\x1d\n\nrule_count\x18\x01 \x01(\x05R\truleCount\x12\x1b\n\tvpc_count\x18\x02 \x01(\x05R\x08vpcCount\x12!\n\x0csubnet_count\x18\x03 \x01(\x05R\x0bsubnetCount\x12\x1d\n\nvnic_count\x18\x04 \x01(\x05R\tvnicCount\x12U\n\x0ehw_pool_handle\x18\x05 \x01(\x0b\x32/.opi_api.network.opinetcommon.v1alpha1.HwHandleR\x0chwPoolHandle\x12L\n\thw_handle\x18\x06 \x01(\x0b\x32/.opi_api.network.opinetcommon.v1alpha1.HwHandleR\x08hwHandle\x12.\n\x13policy_base_address\x18\x07 \x01(\x04R\x11policyBaseAddress\"\x84\x02\n\x0cSecurityRule\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x44\n\x04spec\x18\x02 \x01(\x0b\x32\x30.opi_api.network.cloud.v1alpha1.SecurityRuleSpecR\x04spec\x12J\n\x06status\x18\x03 \x01(\x0b\x32\x32.opi_api.network.cloud.v1alpha1.SecurityRuleStatusR\x06status:N\xea\x41K\n+opi_api.network.cloud.v1alpha1/securityrule\x12\x1csecurityrules/{securityrule}\"\x94\x01\n\x10SecurityRuleSpec\x12\x37\n\x18security_policy_name_ref\x18\x01 \x01(\tR\x15securityPolicyNameRef\x12G\n\x05\x61ttrs\x18\x02 \x01(\x0b\x32\x31.opi_api.network.cloud.v1alpha1.SecurityRuleAttrsR\x05\x61ttrs\"\x14\n\x12SecurityRuleStatus\"\x96\x02\n\x0fSecurityProfile\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12G\n\x04spec\x18\x02 \x01(\x0b\x32\x33.opi_api.network.cloud.v1alpha1.SecurityProfileSpecR\x04spec\x12M\n\x06status\x18\x03 \x01(\x0b\x32\x35.opi_api.network.cloud.v1alpha1.SecurityProfileStatusR\x06status:W\xea\x41T\n.opi_api.network.cloud.v1alpha1/securityprofile\x12\"securityprofiles/{securityprofile}\"\xf0\x05\n\x13SecurityProfileSpec\x12<\n\x1a\x63onnection_tracking_enable\x18\x01 \x01(\x08R\x18\x63onnectionTrackingEnable\x12*\n\x11rule_stats_enable\x18\x02 \x01(\x08R\x0fruleStatsEnable\x12q\n\x17\x64\x65\x66\x61ult_firewall_action\x18\x03 \x01(\x0e\x32\x39.opi_api.network.opinetcommon.v1alpha1.SecurityRuleActionR\x15\x64\x65\x66\x61ultFirewallAction\x12(\n\x10tcp_idle_timeout\x18\x04 \x01(\x05R\x0etcpIdleTimeout\x12(\n\x10udp_idle_timeout\x18\x05 \x01(\x05R\x0eudpIdleTimeout\x12*\n\x11icmp_idle_timeout\x18\x06 \x01(\x05R\x0ficmpIdleTimeout\x12,\n\x12other_idle_timeout\x18\x07 \x01(\x05R\x10otherIdleTimeout\x12?\n\x1ctcp_connection_setup_timeout\x18\x08 \x01(\x05R\x19tcpConnectionSetupTimeout\x12\x33\n\x16tcp_half_close_timeout\x18\t \x01(\x05R\x13tcpHalfCloseTimeout\x12*\n\x11tcp_close_timeout\x18\n \x01(\x05R\x0ftcpCloseTimeout\x12(\n\x10tcp_dorp_timeout\x18\x0b \x01(\x05R\x0etcpDorpTimeout\x12(\n\x10udp_drop_timeout\x18\x0c \x01(\x05R\x0eudpDropTimeout\x12*\n\x11icmp_drop_timeout\x18\r \x01(\x05R\x0ficmpDropTimeout\x12,\n\x12other_drop_timeout\x18\x0e \x01(\x05R\x10otherDropTimeout\"\x17\n\x15SecurityProfileStatus\"\xa9\x03\n\x11PolicyLookupMatch\x12M\n\tsource_ip\x18\x01 \x01(\x0b\x32\x30.opi_api.network.opinetcommon.v1alpha1.IPAddressR\x08sourceIp\x12\x1f\n\x0bsource_tags\x18\x02 \x03(\rR\nsourceTags\x12W\n\x0e\x64\x65stination_ip\x18\x03 \x01(\x0b\x32\x30.opi_api.network.opinetcommon.v1alpha1.IPAddressR\rdestinationIp\x12)\n\x10\x64\x65stination_tags\x18\x04 \x03(\rR\x0f\x64\x65stinationTags\x12\x1a\n\x08protocol\x18\x05 \x01(\x05R\x08protocol\x12\x1f\n\x0bsource_port\x18\x06 \x01(\x05R\nsourcePort\x12)\n\x10\x64\x65stination_port\x18\x07 \x01(\x05R\x0f\x64\x65stinationPort\x12\x1b\n\ticmp_type\x18\x08 \x01(\x05R\x08icmpType\x12\x1b\n\ticmp_code\x18\t \x01(\x05R\x08icmpCode\"\x8c\x04\n\x1bSecurityPolicyLookupRequest\x12(\n\x0fpolicy_name_ref\x18\x01 \x01(\tH\x00R\rpolicyNameRef\x12v\n\x10vnic_lookup_info\x18\x02 \x01(\x0b\x32J.opi_api.network.cloud.v1alpha1.SecurityPolicyLookupRequest.VnicLookupInfoH\x00R\x0evnicLookupInfo\x12T\n\x0cmatch_fields\x18\x03 \x01(\x0b\x32\x31.opi_api.network.cloud.v1alpha1.PolicyLookupMatchR\x0bmatchFields\x1a\xe5\x01\n\x0eVnicLookupInfo\x12\"\n\rvnic_name_ref\x18\x01 \x01(\tR\x0bvnicNameRef\x12[\n\x10policy_direction\x18\x02 \x01(\x0e\x32\x30.opi_api.network.opinetcommon.v1alpha1.PolicyDirR\x0fpolicyDirection\x12R\n\x0e\x61\x64\x64ress_family\x18\x03 \x01(\x0e\x32+.opi_api.network.opinetcommon.v1alpha1.IpAfR\raddressFamilyB\r\n\x0blookup_info\"\xc0\x02\n\x12PolicyLookupResult\x12U\n\x0erule_hw_handle\x18\x01 \x01(\x0b\x32/.opi_api.network.opinetcommon.v1alpha1.HwHandleR\x0cruleHwHandle\x12\x1a\n\x08priority\x18\x02 \x01(\x05R\x08priority\x12Q\n\x06\x61\x63tion\x18\x03 \x01(\x0e\x32\x39.opi_api.network.opinetcommon.v1alpha1.SecurityRuleActionR\x06\x61\x63tion\x12\x42\n\x08\x61lg_type\x18\x04 \x01(\x0e\x32\'.opi_api.network.cloud.v1alpha1.ALGTypeR\x07\x61lgType\x12 \n\x0bterminating\x18\x05 \x01(\x08R\x0bterminating*~\n\x12SecurityPolicyType\x12$\n SECURITY_POLICY_TYPE_UNSPECIFIED\x10\x00\x12!\n\x1dSECURITY_POLICY_TYPE_UNDERLAY\x10\x01\x12\x1f\n\x1bSECURITY_POLICY_TYPE_TENANT\x10\x02*\x96\x01\n\x07\x41LGType\x12\x18\n\x14\x41LG_TYPE_UNSPECIFIED\x10\x00\x12\x11\n\rALG_TYPE_TFTP\x10\x01\x12\x10\n\x0c\x41LG_TYPE_FTP\x10\x02\x12\x10\n\x0c\x41LG_TYPE_DNS\x10\x03\x12\x13\n\x0f\x41LG_TYPE_SUNRPC\x10\x04\x12\x12\n\x0e\x41LG_TYPE_MSRPC\x10\x05\x12\x11\n\rALG_TYPE_RTSP\x10\x06*x\n\x10PolicyRuleFormat\x12\"\n\x1ePOLICY_RULE_FORMAT_UNSPECIFIED\x10\x00\x12 \n\x1cPOLICY_RULE_FORMAT_FLATTENED\x10\x01\x12\x1e\n\x1aPOLICY_RULE_FORMAT_COMPACT\x10\x02\x42s\n\x1eopi_api.network.cloud.v1alpha1B\x12NetworkPolicyProtoP\x01Z;github.com/opiproject/opi-api/network/cloud/v1alpha1/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'networkpolicy_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036opi_api.network.cloud.v1alpha1B\022NetworkPolicyProtoP\001Z;github.com/opiproject/opi-api/network/cloud/v1alpha1/gen/go'
  _globals['_SECURITYPOLICY']._options = None
  _globals['_SECURITYPOLICY']._serialized_options = b'\352AQ\n-opi_api.network.cloud.v1alpha1/securitypolicy\022 securitypolicys/{securitypolicy}'
  _globals['_SECURITYRULE']._options = None
  _globals['_SECURITYRULE']._serialized_options = b'\352AK\n+opi_api.network.cloud.v1alpha1/securityrule\022\034securityrules/{securityrule}'
  _globals['_SECURITYPROFILE']._options = None
  _globals['_SECURITYPROFILE']._serialized_options = b'\352AT\n.opi_api.network.cloud.v1alpha1/securityprofile\022\"securityprofiles/{securityprofile}'
  _globals['_SECURITYPOLICYTYPE']._serialized_start=5375
  _globals['_SECURITYPOLICYTYPE']._serialized_end=5501
  _globals['_ALGTYPE']._serialized_start=5504
  _globals['_ALGTYPE']._serialized_end=5654
  _globals['_POLICYRULEFORMAT']._serialized_start=5656
  _globals['_POLICYRULEFORMAT']._serialized_end=5776
  _globals['_SECURITYPOLICY']._serialized_start=103
  _globals['_SECURITYPOLICY']._serialized_end=375
  _globals['_SECURITYPOLICYSPEC']._serialized_start=378
  _globals['_SECURITYPOLICYSPEC']._serialized_end=854
  _globals['_SECURITYRULEINFO']._serialized_start=856
  _globals['_SECURITYRULEINFO']._serialized_end=976
  _globals['_SECURITYRULEATTRS']._serialized_start=979
  _globals['_SECURITYRULEATTRS']._serialized_end=1283
  _globals['_FTPOPTIONS']._serialized_start=1285
  _globals['_FTPOPTIONS']._serialized_end=1341
  _globals['_DNSOPTIONS']._serialized_start=1344
  _globals['_DNSOPTIONS']._serialized_end=1678
  _globals['_MSRPCOPTIONS']._serialized_start=1680
  _globals['_MSRPCOPTIONS']._serialized_end=1725
  _globals['_SUNRPCOPTIONS']._serialized_start=1727
  _globals['_SUNRPCOPTIONS']._serialized_end=1773
  _globals['_ALGSPEC']._serialized_start=1776
  _globals['_ALGSPEC']._serialized_end=2234
  _globals['_SECURITYPOLICYSTATUS']._serialized_start=2237
  _globals['_SECURITYPOLICYSTATUS']._serialized_end=2598
  _globals['_SECURITYRULE']._serialized_start=2601
  _globals['_SECURITYRULE']._serialized_end=2861
  _globals['_SECURITYRULESPEC']._serialized_start=2864
  _globals['_SECURITYRULESPEC']._serialized_end=3012
  _globals['_SECURITYRULESTATUS']._serialized_start=3014
  _globals['_SECURITYRULESTATUS']._serialized_end=3034
  _globals['_SECURITYPROFILE']._serialized_start=3037
  _globals['_SECURITYPROFILE']._serialized_end=3315
  _globals['_SECURITYPROFILESPEC']._serialized_start=3318
  _globals['_SECURITYPROFILESPEC']._serialized_end=4070
  _globals['_SECURITYPROFILESTATUS']._serialized_start=4072
  _globals['_SECURITYPROFILESTATUS']._serialized_end=4095
  _globals['_POLICYLOOKUPMATCH']._serialized_start=4098
  _globals['_POLICYLOOKUPMATCH']._serialized_end=4523
  _globals['_SECURITYPOLICYLOOKUPREQUEST']._serialized_start=4526
  _globals['_SECURITYPOLICYLOOKUPREQUEST']._serialized_end=5050
  _globals['_SECURITYPOLICYLOOKUPREQUEST_VNICLOOKUPINFO']._serialized_start=4806
  _globals['_SECURITYPOLICYLOOKUPREQUEST_VNICLOOKUPINFO']._serialized_end=5035
  _globals['_POLICYLOOKUPRESULT']._serialized_start=5053
  _globals['_POLICYLOOKUPRESULT']._serialized_end=5373
# @@protoc_insertion_point(module_scope)



import logging

import redfish


class UpdateService:
    def __init__(self, host, user, password, **kwargs):
        """
        Create a new connection to DPU via Redfish.
        Due to timeout restrictions, every command will start its own session
        and tear it down once it completes.
        """
        self.logger = logging.getLogger("dpuredfish")
        self._host = host
        self._user = user
        self._password = password
        self.logger.info("Connecting to %s", host)
        self._session = redfish.redfish_client(
            base_url=self._host,
            username=self._user,
            password=self._password,
            cafile=None,
            capath=None,
            max_retry=3,
            timeout=120,
            **kwargs
        )

    def get_version(self, module):
        return self._session.get(
            "/redfish/v1/UpdateService/FirmwareInventory/{}".format(module)
        ).dict.get("Version")

    def get_versions(self):
        self.logger.info("Getting Versions...")
        # TODO: create decorator for login/logout
        self._session.login(auth=redfish.AuthMethod.SESSION)
        response = self._session.get(
            "/redfish/v1/UpdateService/FirmwareInventory?$expand=.($levels=1)"
        )
        if "error" in response.dict or "Members" not in response.dict:
            error_message = "\n".join(
                msg.get("Message") for msg in response.dict.get("Messages", [])
            )
            raise RuntimeError(
                "Unable to get firmware list: HTTP {}: {}".format(
                    response.status, error_message
                )
            )
        return dict(
            (i.get("Id"), i.get("Version")) for i in response.dict.get("Members")
        )



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import ipsec_pb2 as ipsec__pb2


class IPsecServiceStub(object):
    """Service functions for IPSec Protocol 
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.IPsecVersion = channel.unary_unary(
                '/opi_api.security.v1.IPsecService/IPsecVersion',
                request_serializer=ipsec__pb2.IPsecVersionRequest.SerializeToString,
                response_deserializer=ipsec__pb2.IPsecVersionResponse.FromString,
                )
        self.IPsecStats = channel.unary_unary(
                '/opi_api.security.v1.IPsecService/IPsecStats',
                request_serializer=ipsec__pb2.IPsecStatsRequest.SerializeToString,
                response_deserializer=ipsec__pb2.IPsecStatsResponse.FromString,
                )
        self.IPsecInitiate = channel.unary_unary(
                '/opi_api.security.v1.IPsecService/IPsecInitiate',
                request_serializer=ipsec__pb2.IPsecInitiateRequest.SerializeToString,
                response_deserializer=ipsec__pb2.IPsecInitiateResponse.FromString,
                )
        self.IPsecTerminate = channel.unary_unary(
                '/opi_api.security.v1.IPsecService/IPsecTerminate',
                request_serializer=ipsec__pb2.IPsecTerminateRequest.SerializeToString,
                response_deserializer=ipsec__pb2.IPsecTerminateResponse.FromString,
                )
        self.IPsecRekey = channel.unary_unary(
                '/opi_api.security.v1.IPsecService/IPsecRekey',
                request_serializer=ipsec__pb2.IPsecRekeyRequest.SerializeToString,
                response_deserializer=ipsec__pb2.IPsecRekeyResponse.FromString,
                )
        self.IPsecListSas = channel.unary_unary(
                '/opi_api.security.v1.IPsecService/IPsecListSas',
                request_serializer=ipsec__pb2.IPsecListSasRequest.SerializeToString,
                response_deserializer=ipsec__pb2.IPsecListSasResponse.FromString,
                )
        self.IPsecListConns = channel.unary_unary(
                '/opi_api.security.v1.IPsecService/IPsecListConns',
                request_serializer=ipsec__pb2.IPsecListConnsRequest.SerializeToString,
                response_deserializer=ipsec__pb2.IPsecListConnsResponse.FromString,
                )
        self.IPsecListCerts = channel.unary_unary(
                '/opi_api.security.v1.IPsecService/IPsecListCerts',
                request_serializer=ipsec__pb2.IPsecListCertsRequest.SerializeToString,
                response_deserializer=ipsec__pb2.IPsecListCertsResponse.FromString,
                )
        self.IPsecLoadConn = channel.unary_unary(
                '/opi_api.security.v1.IPsecService/IPsecLoadConn',
                request_serializer=ipsec__pb2.IPsecLoadConnRequest.SerializeToString,
                response_deserializer=ipsec__pb2.IPsecLoadConnResponse.FromString,
                )
        self.IPsecUnloadConn = channel.unary_unary(
                '/opi_api.security.v1.IPsecService/IPsecUnloadConn',
                request_serializer=ipsec__pb2.IPsecUnloadConnRequest.SerializeToString,
                response_deserializer=ipsec__pb2.IPsecUnloadConnResponse.FromString,
                )


class IPsecServiceServicer(object):
    """Service functions for IPSec Protocol 
    """

    def IPsecVersion(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def IPsecStats(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def IPsecInitiate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def IPsecTerminate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def IPsecRekey(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def IPsecListSas(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def IPsecListConns(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def IPsecListCerts(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def IPsecLoadConn(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def IPsecUnloadConn(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_IPsecServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'IPsecVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.IPsecVersion,
                    request_deserializer=ipsec__pb2.IPsecVersionRequest.FromString,
                    response_serializer=ipsec__pb2.IPsecVersionResponse.SerializeToString,
            ),
            'IPsecStats': grpc.unary_unary_rpc_method_handler(
                    servicer.IPsecStats,
                    request_deserializer=ipsec__pb2.IPsecStatsRequest.FromString,
                    response_serializer=ipsec__pb2.IPsecStatsResponse.SerializeToString,
            ),
            'IPsecInitiate': grpc.unary_unary_rpc_method_handler(
                    servicer.IPsecInitiate,
                    request_deserializer=ipsec__pb2.IPsecInitiateRequest.FromString,
                    response_serializer=ipsec__pb2.IPsecInitiateResponse.SerializeToString,
            ),
            'IPsecTerminate': grpc.unary_unary_rpc_method_handler(
                    servicer.IPsecTerminate,
                    request_deserializer=ipsec__pb2.IPsecTerminateRequest.FromString,
                    response_serializer=ipsec__pb2.IPsecTerminateResponse.SerializeToString,
            ),
            'IPsecRekey': grpc.unary_unary_rpc_method_handler(
                    servicer.IPsecRekey,
                    request_deserializer=ipsec__pb2.IPsecRekeyRequest.FromString,
                    response_serializer=ipsec__pb2.IPsecRekeyResponse.SerializeToString,
            ),
            'IPsecListSas': grpc.unary_unary_rpc_method_handler(
                    servicer.IPsecListSas,
                    request_deserializer=ipsec__pb2.IPsecListSasRequest.FromString,
                    response_serializer=ipsec__pb2.IPsecListSasResponse.SerializeToString,
            ),
            'IPsecListConns': grpc.unary_unary_rpc_method_handler(
                    servicer.IPsecListConns,
                    request_deserializer=ipsec__pb2.IPsecListConnsRequest.FromString,
                    response_serializer=ipsec__pb2.IPsecListConnsResponse.SerializeToString,
            ),
            'IPsecListCerts': grpc.unary_unary_rpc_method_handler(
                    servicer.IPsecListCerts,
                    request_deserializer=ipsec__pb2.IPsecListCertsRequest.FromString,
                    response_serializer=ipsec__pb2.IPsecListCertsResponse.SerializeToString,
            ),
            'IPsecLoadConn': grpc.unary_unary_rpc_method_handler(
                    servicer.IPsecLoadConn,
                    request_deserializer=ipsec__pb2.IPsecLoadConnRequest.FromString,
                    response_serializer=ipsec__pb2.IPsecLoadConnResponse.SerializeToString,
            ),
            'IPsecUnloadConn': grpc.unary_unary_rpc_method_handler(
                    servicer.IPsecUnloadConn,
                    request_deserializer=ipsec__pb2.IPsecUnloadConnRequest.FromString,
                    response_serializer=ipsec__pb2.IPsecUnloadConnResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'opi_api.security.v1.IPsecService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class IPsecService(object):
    """Service functions for IPSec Protocol 
    """

    @staticmethod
    def IPsecVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.security.v1.IPsecService/IPsecVersion',
            ipsec__pb2.IPsecVersionRequest.SerializeToString,
            ipsec__pb2.IPsecVersionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def IPsecStats(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.security.v1.IPsecService/IPsecStats',
            ipsec__pb2.IPsecStatsRequest.SerializeToString,
            ipsec__pb2.IPsecStatsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def IPsecInitiate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.security.v1.IPsecService/IPsecInitiate',
            ipsec__pb2.IPsecInitiateRequest.SerializeToString,
            ipsec__pb2.IPsecInitiateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def IPsecTerminate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.security.v1.IPsecService/IPsecTerminate',
            ipsec__pb2.IPsecTerminateRequest.SerializeToString,
            ipsec__pb2.IPsecTerminateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def IPsecRekey(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.security.v1.IPsecService/IPsecRekey',
            ipsec__pb2.IPsecRekeyRequest.SerializeToString,
            ipsec__pb2.IPsecRekeyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def IPsecListSas(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.security.v1.IPsecService/IPsecListSas',
            ipsec__pb2.IPsecListSasRequest.SerializeToString,
            ipsec__pb2.IPsecListSasResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def IPsecListConns(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.security.v1.IPsecService/IPsecListConns',
            ipsec__pb2.IPsecListConnsRequest.SerializeToString,
            ipsec__pb2.IPsecListConnsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def IPsecListCerts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.security.v1.IPsecService/IPsecListCerts',
            ipsec__pb2.IPsecListCertsRequest.SerializeToString,
            ipsec__pb2.IPsecListCertsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def IPsecLoadConn(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.security.v1.IPsecService/IPsecLoadConn',
            ipsec__pb2.IPsecLoadConnRequest.SerializeToString,
            ipsec__pb2.IPsecLoadConnResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def IPsecUnloadConn(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.security.v1.IPsecService/IPsecUnloadConn',
            ipsec__pb2.IPsecUnloadConnRequest.SerializeToString,
            ipsec__pb2.IPsecUnloadConnResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# SPDX-License-Identifier: Apache-2.0
# Copyright (c) 2022 Dell Inc, or its subsidiaries.

import ipaddress
import uuid

import grpc
from google.protobuf import field_mask_pb2, wrappers_pb2

from .proto.v1 import (
    backend_nvme_pb2,
    backend_nvme_pb2_grpc,
    frontend_nvme_pb2,
    frontend_nvme_pb2_grpc,
    opicommon_pb2,
)


class NvmeSubsystem:
    """An object representing Nvme subsystem.
    Args:
        nqn:    per Nvme spec each subsystem has an Nvme Qualified Name.
        model:  model number of the subsystem that will be visible to host.
        serial: serial number of the subsystem that will be visible to host.
        ns:     max amount of namespaces allowed in this subsystem.
    """

    def __repr__(self) -> str:
        return f"{type(self).__name__}({str(self.id)}, nqn={str(self.nqn)})"

    def __init__(self, nqn: str, model="OPI Model", serial="OPI SN", ns=10) -> None:
        self.id = "opi-" + str(uuid.uuid1())
        self.name = "nvmeSubsystems/" + str(self.id)
        self.nqn = nqn
        self.model = model
        self.serial = serial
        self.ns = ns

    def create(self, address):
        with grpc.insecure_channel(address) as channel:
            stub = frontend_nvme_pb2_grpc.FrontendNvmeServiceStub(channel)
            res = stub.CreateNvmeSubsystem(
                request=frontend_nvme_pb2.CreateNvmeSubsystemRequest(
                    nvme_subsystem_id=str(self.id),
                    nvme_subsystem=frontend_nvme_pb2.NvmeSubsystem(
                        spec=frontend_nvme_pb2.NvmeSubsystemSpec(
                            model_number=self.model,
                            serial_number=self.serial,
                            max_namespaces=self.ns,
                            nqn=self.nqn,
                        )
                    ),
                )
            )
            return res

    def update(self, address):
        with grpc.insecure_channel(address) as channel:
            stub = frontend_nvme_pb2_grpc.FrontendNvmeServiceStub(channel)
            res = stub.UpdateNvmeSubsystem(
                request=frontend_nvme_pb2.UpdateNvmeSubsystemRequest(
                    update_mask=field_mask_pb2.FieldMask(paths=["*"]),
                    nvme_subsystem=frontend_nvme_pb2.NvmeSubsystem(
                        name=self.name,
                        spec=frontend_nvme_pb2.NvmeSubsystemSpec(
                            model_number=self.model,
                            serial_number=self.serial,
                            max_namespaces=self.ns,
                            nqn=self.nqn,
                        ),
                    ),
                )
            )
            return res

    def list(self, address):
        with grpc.insecure_channel(address) as channel:
            stub = frontend_nvme_pb2_grpc.FrontendNvmeServiceStub(channel)
            res = stub.ListNvmeSubsystems(
                request=frontend_nvme_pb2.ListNvmeSubsystemsRequest()
            )
            return res

    def delete(self, address):
        with grpc.insecure_channel(address) as channel:
            stub = frontend_nvme_pb2_grpc.FrontendNvmeServiceStub(channel)
            res = stub.DeleteNvmeSubsystem(
                request=frontend_nvme_pb2.DeleteNvmeSubsystemRequest(
                    name=self.name,
                )
            )
            return res

    def get(self, address):
        with grpc.insecure_channel(address) as channel:
            stub = frontend_nvme_pb2_grpc.FrontendNvmeServiceStub(channel)
            res = stub.GetNvmeSubsystem(
                request=frontend_nvme_pb2.GetNvmeSubsystemRequest(
                    name=self.name,
                )
            )
            return res

    def stats(self, address):
        with grpc.insecure_channel(address) as channel:
            stub = frontend_nvme_pb2_grpc.FrontendNvmeServiceStub(channel)
            res = stub.StatsNvmeSubsystem(
                request=frontend_nvme_pb2.StatsNvmeSubsystemRequest(
                    name=self.name,
                )
            )
            return res


class NvmeController:
    """An object representing Nvme controller.
    Args:
        subsystem: substsem name that controller belongs to.
        queue:     queue depth for both SQ (submition) and CQ (completion).
        pf:        physical_function of PciEndpoint.
        vf:        virtual_function of PciEndpoint.
        port:      port_id of PciEndpoint.
        max_nsq:   maximum number of host submission queues allowed.
                   For 0 the xPU will provide a default.
        max_ncq:   maximum number of host completion queues allowed.
                   For 0 the xPU will provide a default.
    """

    def __repr__(self) -> str:
        return (
            f"{type(self).__name__}({str(self.id)}, nqn={str(self.queue)}, "
            + f"port={str(self.port)}, pf={str(self.pf)}, vf={self.vf}, "
            + f"max_nsq={str(self.max_nsq)}, max_ncq={self.max_ncq})"
        )

    def __init__(
        self,
        subsystem: NvmeSubsystem,
        queue: int,
        pf: int,
        vf: int,
        port: int = 0,
        max_nsq: int = 0,
        max_ncq: int = 0,
    ) -> None:
        self.id = "opi-" + str(uuid.uuid1())
        self.name = "nvmeSubsystems/{}/nvmeControllers/{}".format(subsystem.id, self.id)
        self.subsystem = subsystem
        self.queue = queue
        self.pf = pf
        self.vf = vf
        self.port = port
        self.max_nsq = max_nsq
        self.max_ncq = max_ncq

    def create(self, address):
        with grpc.insecure_channel(address) as channel:
            stub = frontend_nvme_pb2_grpc.FrontendNvmeServiceStub(channel)
            res = stub.CreateNvmeController(
                request=frontend_nvme_pb2.CreateNvmeControllerRequest(
                    parent=str(self.subsystem.name),
                    nvme_controller_id=str(self.id),
                    nvme_controller=frontend_nvme_pb2.NvmeController(
                        spec=frontend_nvme_pb2.NvmeControllerSpec(
                            trtype=opicommon_pb2.NVME_TRANSPORT_TYPE_PCIE,
                            pcie_id=opicommon_pb2.PciEndpoint(
                                physical_function=wrappers_pb2.Int32Value(
                                    value=self.pf
                                ),
                                virtual_function=wrappers_pb2.Int32Value(value=self.vf),
                                port_id=wrappers_pb2.Int32Value(value=self.port),
                            ),
                            max_nsq=self.max_nsq,
                            max_ncq=self.max_ncq,
                            sqes=7,
                            cqes=8,
                            nvme_controller_id=1,
                        )
                    ),
                )
            )
            return res

    def update(self, address):
        with grpc.insecure_channel(address) as channel:
            stub = frontend_nvme_pb2_grpc.FrontendNvmeServiceStub(channel)
            res = stub.UpdateNvmeController(
                request=frontend_nvme_pb2.UpdateNvmeControllerRequest(
                    update_mask=field_mask_pb2.FieldMask(paths=["*"]),
                    nvme_controller=frontend_nvme_pb2.NvmeController(
                        name=self.name,
                        spec=frontend_nvme_pb2.NvmeControllerSpec(
                            pcie_id=opicommon_pb2.PciEndpoint(
                                physical_function=1, virtual_function=2, port_id=3
                            ),
                            max_nsq=5,
                            max_ncq=6,
                            sqes=7,
                            cqes=8,
                            nvme_controller_id=1,
                        ),
                    ),
                )
            )
            return res

    def list(self, address):
        with grpc.insecure_channel(address) as channel:
            stub = frontend_nvme_pb2_grpc.FrontendNvmeServiceStub(channel)
            res = stub.ListNvmeControllers(
                request=frontend_nvme_pb2.ListNvmeControllersRequest(
                    parent=str(self.subsystem.name)
                )
            )
            return res

    def delete(self, address):
        with grpc.insecure_channel(address) as channel:
            stub = frontend_nvme_pb2_grpc.FrontendNvmeServiceStub(channel)
            res = stub.DeleteNvmeController(
                request=frontend_nvme_pb2.DeleteNvmeControllerRequest(
                    name=self.name,
                )
            )
            return res

    def get(self, address):
        with grpc.insecure_channel(address) as channel:
            stub = frontend_nvme_pb2_grpc.FrontendNvmeServiceStub(channel)
            res = stub.GetNvmeController(
                request=frontend_nvme_pb2.GetNvmeControllerRequest(
                    name=self.name,
                )
            )
            return res

    def stats(self, address):
        with grpc.insecure_channel(address) as channel:
            stub = frontend_nvme_pb2_grpc.FrontendNvmeServiceStub(channel)
            res = stub.StatsNvmeController(
                request=frontend_nvme_pb2.StatsNvmeControllerRequest(
                    name=self.name,
                )
            )
            return res


class NvmeNamespace:
    """An object representing Nvme namespace.
    Args:
        subsystem: subsystem name that controller belongs to.
        volume:    backend volume to connect the namespace to.
    """

    def __repr__(self) -> str:
        return f"{type(self).__name__}({str(self.id)}, volume={str(self.volume)})"

    def __init__(self, subsystem: NvmeSubsystem, volume: str) -> None:
        self.id = "opi-" + str(uuid.uuid1())
        self.name = "nvmeSubsystems/{}/nvmeNamespaces/{}".format(subsystem.id, self.id)
        self.subsystem = subsystem
        self.volume = volume

    def create(self, address):
        with grpc.insecure_channel(address) as channel:
            stub = frontend_nvme_pb2_grpc.FrontendNvmeServiceStub(channel)
            res = stub.CreateNvmeNamespace(
                request=frontend_nvme_pb2.CreateNvmeNamespaceRequest(
                    parent=str(self.subsystem.name),
                    nvme_namespace_id=str(self.id),
                    nvme_namespace=frontend_nvme_pb2.NvmeNamespace(
                        spec=frontend_nvme_pb2.NvmeNamespaceSpec(
                            volume_name_ref=self.volume,
                            uuid="1b4e28ba-2fa1-11d2-883f-b9a761bde3fb",
                            nguid="1b4e28ba-2fa1-11d2-883f-b9a761bde3fb",
                            eui64=1967554867335598546,
                            host_nsid=1,
                        )
                    ),
                )
            )
            return res

    def update(self, address):
        with grpc.insecure_channel(address) as channel:
            stub = frontend_nvme_pb2_grpc.FrontendNvmeServiceStub(channel)
            res = stub.UpdateNvmeNamespace(
                request=frontend_nvme_pb2.UpdateNvmeNamespaceRequest(
                    update_mask=field_mask_pb2.FieldMask(paths=["*"]),
                    nvme_namespace=frontend_nvme_pb2.NvmeNamespace(
                        name=self.name,
                        spec=frontend_nvme_pb2.NvmeNamespaceSpec(
                            volume_name_ref="Malloc1",
                            uuid="1b4e28ba-2fa1-11d2-883f-b9a761bde3fb",
                            nguid="1b4e28ba-2fa1-11d2-883f-b9a761bde3fb",
                            eui64=1967554867335598546,
                            host_nsid=1,
                        ),
                    ),
                )
            )
            return res

    def list(self, address):
        with grpc.insecure_channel(address) as channel:
            stub = frontend_nvme_pb2_grpc.FrontendNvmeServiceStub(channel)
            res = stub.ListNvmeNamespaces(
                request=frontend_nvme_pb2.ListNvmeNamespacesRequest(
                    parent=str(self.subsystem.name)
                )
            )
            return res

    def delete(self, address):
        with grpc.insecure_channel(address) as channel:
            stub = frontend_nvme_pb2_grpc.FrontendNvmeServiceStub(channel)
            res = stub.DeleteNvmeNamespace(
                request=frontend_nvme_pb2.DeleteNvmeNamespaceRequest(
                    name=self.name,
                )
            )
            return res

    def get(self, address):
        with grpc.insecure_channel(address) as channel:
            stub = frontend_nvme_pb2_grpc.FrontendNvmeServiceStub(channel)
            res = stub.GetNvmeNamespace(
                request=frontend_nvme_pb2.GetNvmeNamespaceRequest(
                    name=self.name,
                )
            )
            return res

    def stats(self, address):
        with grpc.insecure_channel(address) as channel:
            stub = frontend_nvme_pb2_grpc.FrontendNvmeServiceStub(channel)
            res = stub.StatsNvmeNamespace(
                request=frontend_nvme_pb2.StatsNvmeNamespaceRequest(
                    name=self.name,
                )
            )
            return res


class NvmeRemoteController:
    """An object representing Nvme remote controller.
    Args:
        multipath:  multipath mode:
            backend_nvme_pb2.NVME_MULTIPATH_DISABLE,
            backend_nvme_pb2.NVME_MULTIPATH_FAILOVER,
            backend_nvme_pb2.NVME_MULTIPATH_MULTIPATH
        hdgst:      header digest
        ddgst:      data digest
    """

    def __repr__(self) -> str:
        return (
            f"{type(self).__name__}({str(self.id)}, "
            + f"multipath={str(self.multipath)}, hdgst={str(self.hdgst)}, "
            + f"ddgst={str(self.ddgst)})"
        )

    def __init__(self, multipath: int, hdgst: bool, ddgst: bool) -> None:
        self.id = "opi-" + str(uuid.uuid1())
        self.multipath = multipath
        self.hdgst = hdgst
        self.ddgst = ddgst
        self.name = "nvmeRemoteControllers/{}".format(self.id)

    def create(self, address):
        with grpc.insecure_channel(address) as channel:
            stub = backend_nvme_pb2_grpc.NvmeRemoteControllerServiceStub(channel)
            res = stub.CreateNvmeRemoteController(
                request=backend_nvme_pb2.CreateNvmeRemoteControllerRequest(
                    nvme_remote_controller_id=self.id,
                    nvme_remote_controller=backend_nvme_pb2.NvmeRemoteController(
                        multipath=self.multipath,
                        tcp=backend_nvme_pb2.TcpController(
                            hdgst=self.hdgst,
                            ddgst=self.ddgst,
                        ),
                    ),
                )
            )
            return res

    def update(self, address):
        with grpc.insecure_channel(address) as channel:
            stub = backend_nvme_pb2_grpc.NvmeRemoteControllerServiceStub(channel)
            res = stub.UpdateNvmeRemoteController(
                request=backend_nvme_pb2.UpdateNvmeRemoteControllerRequest(
                    update_mask=field_mask_pb2.FieldMask(paths=["*"]),
                    nvme_remote_controller=backend_nvme_pb2.NvmeRemoteController(
                        name=self.name,
                        multipath=self.multipath,
                        tcp=backend_nvme_pb2.TcpController(
                            hdgst=self.hdgst,
                            ddgst=self.ddgst,
                        ),
                    ),
                )
            )
            return res

    def list(self, address):
        with grpc.insecure_channel(address) as channel:
            stub = backend_nvme_pb2_grpc.NvmeRemoteControllerServiceStub(channel)
            res = stub.ListNvmeRemoteControllers(
                request=backend_nvme_pb2.ListNvmeRemoteControllersRequest()
            )
            return res

    def delete(self, address):
        with grpc.insecure_channel(address) as channel:
            stub = backend_nvme_pb2_grpc.NvmeRemoteControllerServiceStub(channel)
            res = stub.DeleteNvmeRemoteController(
                request=backend_nvme_pb2.DeleteNvmeRemoteControllerRequest(
                    name=self.name,
                )
            )
            return res

    def get(self, address):
        with grpc.insecure_channel(address) as channel:
            stub = backend_nvme_pb2_grpc.NvmeRemoteControllerServiceStub(channel)
            res = stub.GetNvmeRemoteController(
                request=backend_nvme_pb2.GetNvmeRemoteControllerRequest(
                    name=self.name,
                )
            )
            return res

    def stats(self, address):
        with grpc.insecure_channel(address) as channel:
            stub = backend_nvme_pb2_grpc.NvmeRemoteControllerServiceStub(channel)
            res = stub.StatsNvmeRemoteController(
                request=backend_nvme_pb2.StatsNvmeRemoteControllerRequest(
                    name=self.name,
                )
            )
            return res


ip_to_grpc_version = {
    4: opicommon_pb2.NVME_ADDRESS_FAMILY_IPV4,
    6: opicommon_pb2.NVME_ADDRESS_FAMILY_IPV6,
}


class NvmeTcpPath:
    """An object representing Nvme TCP path.
    Args:
        ip:         ip address to target controller
        port:       port of target controller
        subnqn:     subsystem nqn
        hostnqn:    host nqn
    """

    def __repr__(self) -> str:
        return (
            f"{type(self).__name__}({str(self.id)}, ip={str(self.ip)}, "
            + f"adrfam={str(self.adrfam)}, port={str(self.port)}), "
            + f"subnqn={str(self.subnqn)}, hostnqn={str(self.hostnqn)}"
        )

    def __init__(
        self,
        remote_controller: NvmeRemoteController,
        ip: str,
        port: int,
        subnqn: str,
        hostnqn: str = "",
    ) -> None:
        self.id = "opi-" + str(uuid.uuid1())
        self.controller = remote_controller
        self.ip = ip
        self.port = port
        self.subnqn = subnqn
        self.hostnqn = hostnqn
        self.name = "nvmeRemoteControllers/{}/nvmePaths/{}".format(
            remote_controller.id, self.id
        )
        self.adrfam = ip_to_grpc_version[ipaddress.ip_address(self.ip).version]

    def create(self, address):
        with grpc.insecure_channel(address) as channel:
            stub = backend_nvme_pb2_grpc.NvmeRemoteControllerServiceStub(channel)
            res = stub.CreateNvmePath(
                request=backend_nvme_pb2.CreateNvmePathRequest(
                    parent=self.controller.name,
                    nvme_path_id=self.id,
                    nvme_path=backend_nvme_pb2.NvmePath(
                        trtype=opicommon_pb2.NVME_TRANSPORT_TYPE_TCP,
                        traddr=self.ip,
                        fabrics=backend_nvme_pb2.FabricsPath(
                            trsvcid=self.port,
                            subnqn=self.subnqn,
                            adrfam=self.adrfam,
                            hostnqn=self.hostnqn,
                        ),
                    ),
                )
            )
            return res

    def update(self, address):
        with grpc.insecure_channel(address) as channel:
            stub = backend_nvme_pb2_grpc.NvmeRemoteControllerServiceStub(channel)
            res = stub.UpdateNvmePath(
                request=backend_nvme_pb2.UpdateNvmePathRequest(
                    update_mask=field_mask_pb2.FieldMask(paths=["*"]),
                    nvme_path=backend_nvme_pb2.NvmePath(
                        name=self.name,
                        trtype=opicommon_pb2.NVME_TRANSPORT_TYPE_TCP,
                        traddr=self.ip,
                        fabrics=backend_nvme_pb2.FabricsPath(
                            trsvcid=self.port,
                            subnqn=self.subnqn,
                            adrfam=self.adrfam,
                            hostnqn=self.hostnqn,
                        ),
                    ),
                )
            )
            return res

    def list(self, address):
        with grpc.insecure_channel(address) as channel:
            stub = backend_nvme_pb2_grpc.NvmeRemoteControllerServiceStub(channel)
            res = stub.ListNvmePaths(
                request=backend_nvme_pb2.ListNvmePathsRequest(
                    parent=self.controller.name
                )
            )
            return res

    def delete(self, address):
        with grpc.insecure_channel(address) as channel:
            stub = backend_nvme_pb2_grpc.NvmeRemoteControllerServiceStub(channel)
            res = stub.DeleteNvmePath(
                request=backend_nvme_pb2.DeleteNvmePathRequest(
                    name=self.name,
                )
            )
            return res

    def get(self, address):
        with grpc.insecure_channel(address) as channel:
            stub = backend_nvme_pb2_grpc.NvmeRemoteControllerServiceStub(channel)
            res = stub.GetNvmePath(
                request=backend_nvme_pb2.GetNvmePathRequest(
                    name=self.name,
                )
            )
            return res

    def stats(self, address):
        with grpc.insecure_channel(address) as channel:
            stub = backend_nvme_pb2_grpc.NvmeRemoteControllerServiceStub(channel)
            res = stub.StatsNvmePath(
                request=backend_nvme_pb2.StatsNvmePathRequest(
                    name=self.name,
                )
            )
            return res



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import backend_null_pb2 as backend__null__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class NullVolumeServiceStub(object):
    """Back End (network-facing) APIs. This is debug interface for null block devices.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateNullVolume = channel.unary_unary(
                '/opi_api.storage.v1.NullVolumeService/CreateNullVolume',
                request_serializer=backend__null__pb2.CreateNullVolumeRequest.SerializeToString,
                response_deserializer=backend__null__pb2.NullVolume.FromString,
                )
        self.DeleteNullVolume = channel.unary_unary(
                '/opi_api.storage.v1.NullVolumeService/DeleteNullVolume',
                request_serializer=backend__null__pb2.DeleteNullVolumeRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateNullVolume = channel.unary_unary(
                '/opi_api.storage.v1.NullVolumeService/UpdateNullVolume',
                request_serializer=backend__null__pb2.UpdateNullVolumeRequest.SerializeToString,
                response_deserializer=backend__null__pb2.NullVolume.FromString,
                )
        self.ListNullVolumes = channel.unary_unary(
                '/opi_api.storage.v1.NullVolumeService/ListNullVolumes',
                request_serializer=backend__null__pb2.ListNullVolumesRequest.SerializeToString,
                response_deserializer=backend__null__pb2.ListNullVolumesResponse.FromString,
                )
        self.GetNullVolume = channel.unary_unary(
                '/opi_api.storage.v1.NullVolumeService/GetNullVolume',
                request_serializer=backend__null__pb2.GetNullVolumeRequest.SerializeToString,
                response_deserializer=backend__null__pb2.NullVolume.FromString,
                )
        self.StatsNullVolume = channel.unary_unary(
                '/opi_api.storage.v1.NullVolumeService/StatsNullVolume',
                request_serializer=backend__null__pb2.StatsNullVolumeRequest.SerializeToString,
                response_deserializer=backend__null__pb2.StatsNullVolumeResponse.FromString,
                )


class NullVolumeServiceServicer(object):
    """Back End (network-facing) APIs. This is debug interface for null block devices.
    """

    def CreateNullVolume(self, request, context):
        """Create an Null Volume
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteNullVolume(self, request, context):
        """Delete an Null Volume
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateNullVolume(self, request, context):
        """Update an Null Volume
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListNullVolumes(self, request, context):
        """List Null Volumes
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNullVolume(self, request, context):
        """Get an Null Volume
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StatsNullVolume(self, request, context):
        """Get an Null Volume statistics
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_NullVolumeServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateNullVolume': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateNullVolume,
                    request_deserializer=backend__null__pb2.CreateNullVolumeRequest.FromString,
                    response_serializer=backend__null__pb2.NullVolume.SerializeToString,
            ),
            'DeleteNullVolume': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteNullVolume,
                    request_deserializer=backend__null__pb2.DeleteNullVolumeRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateNullVolume': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateNullVolume,
                    request_deserializer=backend__null__pb2.UpdateNullVolumeRequest.FromString,
                    response_serializer=backend__null__pb2.NullVolume.SerializeToString,
            ),
            'ListNullVolumes': grpc.unary_unary_rpc_method_handler(
                    servicer.ListNullVolumes,
                    request_deserializer=backend__null__pb2.ListNullVolumesRequest.FromString,
                    response_serializer=backend__null__pb2.ListNullVolumesResponse.SerializeToString,
            ),
            'GetNullVolume': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNullVolume,
                    request_deserializer=backend__null__pb2.GetNullVolumeRequest.FromString,
                    response_serializer=backend__null__pb2.NullVolume.SerializeToString,
            ),
            'StatsNullVolume': grpc.unary_unary_rpc_method_handler(
                    servicer.StatsNullVolume,
                    request_deserializer=backend__null__pb2.StatsNullVolumeRequest.FromString,
                    response_serializer=backend__null__pb2.StatsNullVolumeResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'opi_api.storage.v1.NullVolumeService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class NullVolumeService(object):
    """Back End (network-facing) APIs. This is debug interface for null block devices.
    """

    @staticmethod
    def CreateNullVolume(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.NullVolumeService/CreateNullVolume',
            backend__null__pb2.CreateNullVolumeRequest.SerializeToString,
            backend__null__pb2.NullVolume.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteNullVolume(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.NullVolumeService/DeleteNullVolume',
            backend__null__pb2.DeleteNullVolumeRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateNullVolume(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.NullVolumeService/UpdateNullVolume',
            backend__null__pb2.UpdateNullVolumeRequest.SerializeToString,
            backend__null__pb2.NullVolume.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListNullVolumes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.NullVolumeService/ListNullVolumes',
            backend__null__pb2.ListNullVolumesRequest.SerializeToString,
            backend__null__pb2.ListNullVolumesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetNullVolume(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.NullVolumeService/GetNullVolume',
            backend__null__pb2.GetNullVolumeRequest.SerializeToString,
            backend__null__pb2.NullVolume.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StatsNullVolume(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.NullVolumeService/StatsNullVolume',
            backend__null__pb2.StatsNullVolumeRequest.SerializeToString,
            backend__null__pb2.StatsNullVolumeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: networkvlan.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11networkvlan.proto\x12%opi_api.network.opinetcommon.v1alpha1\"\xdb\x01\n\x13SwitchedVlanSetting\x12\x61\n\x13vlan_interface_mode\x18\x01 \x01(\x0e\x32\x31.opi_api.network.opinetcommon.v1alpha1.VlanIfModeR\x11vlanInterfaceMode\x12\x1f\n\x0bnative_vlan\x18\x02 \x01(\rR\nnativeVlan\x12\x1f\n\x0b\x61\x63\x63\x65ss_vlan\x18\x03 \x01(\rR\naccessVlan\x12\x1f\n\x0btrunk_vlans\x18\x04 \x01(\tR\ntrunkVlans\"\xb6\x01\n\x0eVlanSwitchedIf\x12R\n\x06\x63onfig\x18\x01 \x01(\x0b\x32:.opi_api.network.opinetcommon.v1alpha1.SwitchedVlanSettingR\x06\x63onfig\x12P\n\x05state\x18\x02 \x01(\x0b\x32:.opi_api.network.opinetcommon.v1alpha1.SwitchedVlanSettingR\x05state\"\xdb\x01\n\x18VlanIngressEgressSetting\x12`\n\x0fvlanstackaction\x18\x01 \x01(\x0e\x32\x36.opi_api.network.opinetcommon.v1alpha1.VlanStackActionR\x0fvlanstackaction\x12\x17\n\x07vlan_id\x18\x02 \x01(\rR\x06vlanId\x12\x44\n\x04tpid\x18\x03 \x01(\x0e\x32\x30.opi_api.network.opinetcommon.v1alpha1.TpidTypesR\x04tpid\"\xac\x0c\n\x06VlanIf\x12M\n\x05match\x18\x01 \x01(\x0b\x32\x37.opi_api.network.opinetcommon.v1alpha1.VlanIf.VlanMatchR\x05match\x12h\n\x0eingressmapping\x18\x02 \x01(\x0b\x32@.opi_api.network.opinetcommon.v1alpha1.VlanIf.VlanIngressMappingR\x0eingressmapping\x12\x65\n\regressmapping\x18\x03 \x01(\x0b\x32?.opi_api.network.opinetcommon.v1alpha1.VlanIf.VlanEgressMappingR\regressmapping\x1a\xf4\x06\n\tVlanMatch\x12h\n\x0csingletagged\x18\x01 \x01(\x0b\x32\x44.opi_api.network.opinetcommon.v1alpha1.VlanIf.VlanMatch.SingleTaggedR\x0csingletagged\x12t\n\x10singletaggedlist\x18\x02 \x01(\x0b\x32H.opi_api.network.opinetcommon.v1alpha1.VlanIf.VlanMatch.SingleTaggedListR\x10singletaggedlist\x1a\xbe\x02\n\x0cSingleTagged\x12l\n\x06\x63onfig\x18\x01 \x01(\x0b\x32T.opi_api.network.opinetcommon.v1alpha1.VlanIf.VlanMatch.SingleTagged.SingleTagConfigR\x06\x63onfig\x12i\n\x05state\x18\x02 \x01(\x0b\x32S.opi_api.network.opinetcommon.v1alpha1.VlanIf.VlanMatch.SingleTagged.SingleTagStateR\x05state\x1a*\n\x0fSingleTagConfig\x12\x17\n\x07vlan_id\x18\x01 \x01(\rR\x06vlanId\x1a)\n\x0eSingleTagState\x12\x17\n\x07vlan_id\x18\x01 \x01(\rR\x06vlanId\x1a\xc5\x02\n\x10SingleTaggedList\x12n\n\x06\x63onfig\x18\x01 \x01(\x0b\x32V.opi_api.network.opinetcommon.v1alpha1.VlanIf.VlanMatch.SingleTaggedList.TagListConfigR\x06\x63onfig\x12n\n\x06status\x18\x02 \x01(\x0b\x32V.opi_api.network.opinetcommon.v1alpha1.VlanIf.VlanMatch.SingleTaggedList.TagListStatusR\x06status\x1a(\n\rTagListConfig\x12\x17\n\x07vlan_id\x18\x01 \x03(\rR\x06vlanId\x1a\'\n\rTagListStatus\x12\x16\n\x06vlanid\x18\x01 \x03(\rR\x06vlanid\x1a\xc4\x01\n\x12VlanIngressMapping\x12W\n\x06\x63onfig\x18\x01 \x01(\x0b\x32?.opi_api.network.opinetcommon.v1alpha1.VlanIngressEgressSettingR\x06\x63onfig\x12U\n\x05state\x18\x02 \x01(\x0b\x32?.opi_api.network.opinetcommon.v1alpha1.VlanIngressEgressSettingR\x05state\x1a\xc3\x01\n\x11VlanEgressMapping\x12W\n\x06\x63onfig\x18\x01 \x01(\x0b\x32?.opi_api.network.opinetcommon.v1alpha1.VlanIngressEgressSettingR\x06\x63onfig\x12U\n\x05state\x18\x02 \x01(\x0b\x32?.opi_api.network.opinetcommon.v1alpha1.VlanIngressEgressSettingR\x05state*\x97\x01\n\tTpidTypes\x12\x1a\n\x16TPID_TYPES_UNSPECIFIED\x10\x00\x12\x15\n\x11TPID_TYPES_0X8100\x10\x01\x12\x15\n\x11TPID_TYPES_0X88A8\x10\x02\x12\x15\n\x11TPID_TYPES_0X9100\x10\x03\x12\x15\n\x11TPID_TYPES_0X9200\x10\x04\x12\x12\n\x0eTPID_TYPES_ANY\x10\x05*\x87\x01\n\x0fVlanStackAction\x12!\n\x1dVLAN_STACK_ACTION_UNSPECIFIED\x10\x00\x12\x1a\n\x16VLAN_STACK_ACTION_PUSH\x10\x01\x12\x19\n\x15VLAN_STACK_ACTION_POP\x10\x02\x12\x1a\n\x16VLAN_STACK_ACTION_SWAP\x10\x03*[\n\nVlanIfMode\x12\x1c\n\x18VLAN_IF_MODE_UNSPECIFIED\x10\x00\x12\x17\n\x13VLAN_IF_MODE_ACCESS\x10\x01\x12\x16\n\x12VLAN_IF_MODE_TRUNK\x10\x02\x42\x7f\n%opi_api.network.opinetcommon.v1alpha1B\x10NetworkVlanProtoP\x01ZBgithub.com/opiproject/opi-api/network/opinetcommon/v1alpha1/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'networkvlan_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%opi_api.network.opinetcommon.v1alpha1B\020NetworkVlanProtoP\001ZBgithub.com/opiproject/opi-api/network/opinetcommon/v1alpha1/gen/go'
  _globals['_TPIDTYPES']._serialized_start=2273
  _globals['_TPIDTYPES']._serialized_end=2424
  _globals['_VLANSTACKACTION']._serialized_start=2427
  _globals['_VLANSTACKACTION']._serialized_end=2562
  _globals['_VLANIFMODE']._serialized_start=2564
  _globals['_VLANIFMODE']._serialized_end=2655
  _globals['_SWITCHEDVLANSETTING']._serialized_start=61
  _globals['_SWITCHEDVLANSETTING']._serialized_end=280
  _globals['_VLANSWITCHEDIF']._serialized_start=283
  _globals['_VLANSWITCHEDIF']._serialized_end=465
  _globals['_VLANINGRESSEGRESSSETTING']._serialized_start=468
  _globals['_VLANINGRESSEGRESSSETTING']._serialized_end=687
  _globals['_VLANIF']._serialized_start=690
  _globals['_VLANIF']._serialized_end=2270
  _globals['_VLANIF_VLANMATCH']._serialized_start=989
  _globals['_VLANIF_VLANMATCH']._serialized_end=1873
  _globals['_VLANIF_VLANMATCH_SINGLETAGGED']._serialized_start=1227
  _globals['_VLANIF_VLANMATCH_SINGLETAGGED']._serialized_end=1545
  _globals['_VLANIF_VLANMATCH_SINGLETAGGED_SINGLETAGCONFIG']._serialized_start=1460
  _globals['_VLANIF_VLANMATCH_SINGLETAGGED_SINGLETAGCONFIG']._serialized_end=1502
  _globals['_VLANIF_VLANMATCH_SINGLETAGGED_SINGLETAGSTATE']._serialized_start=1504
  _globals['_VLANIF_VLANMATCH_SINGLETAGGED_SINGLETAGSTATE']._serialized_end=1545
  _globals['_VLANIF_VLANMATCH_SINGLETAGGEDLIST']._serialized_start=1548
  _globals['_VLANIF_VLANMATCH_SINGLETAGGEDLIST']._serialized_end=1873
  _globals['_VLANIF_VLANMATCH_SINGLETAGGEDLIST_TAGLISTCONFIG']._serialized_start=1792
  _globals['_VLANIF_VLANMATCH_SINGLETAGGEDLIST_TAGLISTCONFIG']._serialized_end=1832
  _globals['_VLANIF_VLANMATCH_SINGLETAGGEDLIST_TAGLISTSTATUS']._serialized_start=1834
  _globals['_VLANIF_VLANMATCH_SINGLETAGGEDLIST_TAGLISTSTATUS']._serialized_end=1873
  _globals['_VLANIF_VLANINGRESSMAPPING']._serialized_start=1876
  _globals['_VLANIF_VLANINGRESSMAPPING']._serialized_end=2072
  _globals['_VLANIF_VLANEGRESSMAPPING']._serialized_start=2075
  _globals['_VLANIF_VLANEGRESSMAPPING']._serialized_end=2270
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bgp.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import networktypes_pb2 as networktypes__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\tbgp.proto\x12\x1eopi_api.network.cloud.v1alpha1\x1a\x12networktypes.proto\x1a\x19google/api/resource.proto\"\xce\x01\n\x03\x42gp\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12;\n\x04spec\x18\x02 \x01(\x0b\x32\'.opi_api.network.cloud.v1alpha1.BgpSpecR\x04spec\x12\x41\n\x06status\x18\x03 \x01(\x0b\x32).opi_api.network.cloud.v1alpha1.BgpStatusR\x06status:3\xea\x41\x30\n\"opi_api.network.cloud.v1alpha1/bgp\x12\nbgps/{bgp}\"\xbc\x01\n\x07\x42gpSpec\x12\x1b\n\tlocal_asn\x18\x01 \x01(\rR\x08localAsn\x12\x1b\n\trouter_id\x18\x02 \x01(\x07R\x08routerId\x12\x1d\n\ncluster_id\x18\x03 \x01(\x07R\tclusterId\x12\x18\n\x07\x64isable\x18\x04 \x01(\x08R\x07\x64isable\x12>\n\x1bsuppress_default_resolution\x18\x05 \x01(\x08R\x19suppressDefaultResolution\"\x8f\x02\n\tBgpStatus\x12K\n\noper_state\x18\x01 \x01(\x0e\x32,.opi_api.network.cloud.v1alpha1.BGPOperStateR\toperState\x12\x36\n\x18\x61\x64j_rib_out_routes_count\x18\x02 \x01(\x05R\x14\x61\x64jRibOutRoutesCount\x12;\n\x1bpeak_num_adj_rib_out_routes\x18\x03 \x01(\x05R\x16peakNumAdjRibOutRoutes\x12#\n\rrem_delaytime\x18\x04 \x01(\x05R\x0cremDelaytime\x12\x1b\n\ttable_ver\x18\x05 \x01(\x05R\x08tableVer\"\xe6\x01\n\x07\x42GPPeer\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12?\n\x04spec\x18\x02 \x01(\x0b\x32+.opi_api.network.cloud.v1alpha1.BGPPeerSpecR\x04spec\x12\x45\n\x06status\x18\x03 \x01(\x0b\x32-.opi_api.network.cloud.v1alpha1.BGPPeerStatusR\x06status:?\xea\x41<\n&opi_api.network.cloud.v1alpha1/bgppeer\x12\x12\x62gppeers/{bgppeer}\"\xfd\x04\n\x0b\x42GPPeerSpec\x12G\n\x05state\x18\x01 \x01(\x0e\x32\x31.opi_api.network.opinetcommon.v1alpha1.AdminStateR\x05state\x12U\n\rlocal_address\x18\x02 \x01(\x0b\x32\x30.opi_api.network.opinetcommon.v1alpha1.IPAddressR\x0clocalAddress\x12M\n\tpeer_addr\x18\x03 \x01(\x0b\x32\x30.opi_api.network.opinetcommon.v1alpha1.IPAddressR\x08peerAddr\x12\x1d\n\nremote_asn\x18\x04 \x01(\rR\tremoteAsn\x12\x1b\n\tsend_comm\x18\x05 \x01(\x08R\x08sendComm\x12\"\n\rsend_ext_comm\x18\x06 \x01(\x08R\x0bsendExtComm\x12\x46\n\trr_client\x18\x07 \x01(\x0e\x32).opi_api.network.cloud.v1alpha1.BGPPeerRRR\x08rrClient\x12#\n\rconnect_retry\x18\x08 \x01(\x05R\x0c\x63onnectRetry\x12\x1a\n\x08holdtime\x18\t \x01(\x05R\x08holdtime\x12\x1d\n\nkeep_alive\x18\n \x01(\x05R\tkeepAlive\x12\x1a\n\x08password\x18\x0b \x01(\x0cR\x08password\x12\x10\n\x03ttl\x18\x0c \x01(\x05R\x03ttl\x12#\n\ridle_holdtime\x18\r \x01(\x05R\x0cidleHoldtime\x12$\n\x0e\x61llow_local_as\x18\x0e \x01(\x05R\x0c\x61llowLocalAs\"\xfd\x11\n\rBGPPeerStatus\x12X\n\rsession_state\x18\x01 \x01(\x0e\x32\x33.opi_api.network.cloud.v1alpha1.BGPPeerSessionStateR\x0csessionState\x12\x61\n\x12prev_session_state\x18\x02 \x01(\x0e\x32\x33.opi_api.network.cloud.v1alpha1.BGPPeerSessionStateR\x10prevSessionState\x12&\n\x0flast_error_rcvd\x18\x03 \x01(\x0cR\rlastErrorRcvd\x12&\n\x0flast_error_sent\x18\x04 \x01(\x0cR\rlastErrorSent\x12O\n\nlocal_addr\x18\x05 \x01(\x0b\x32\x30.opi_api.network.opinetcommon.v1alpha1.IPAddressR\tlocalAddr\x12\x1a\n\x08holdtime\x18\x06 \x01(\x05R\x08holdtime\x12\x1c\n\tkeepalive\x18\x07 \x01(\x05R\tkeepalive\x12\x1b\n\tcaps_sent\x18\x08 \x01(\x05R\x08\x63\x61psSent\x12\x1b\n\tcaps_rcvd\x18\t \x01(\x05R\x08\x63\x61psRcvd\x12\x19\n\x08\x63\x61ps_neg\x18\n \x01(\x05R\x07\x63\x61psNeg\x12Z\n\x13sel_local_addr_type\x18\x0b \x01(\x0e\x32+.opi_api.network.cloud.v1alpha1.BGPAddrTypeR\x10selLocalAddrType\x12\x35\n\x16incoming_notifications\x18\x0c \x01(\x05R\x15incomingNotifications\x12\x35\n\x16outbound_notifications\x18\r \x01(\x05R\x15outboundNotifications\x12)\n\x10incoming_updates\x18\x0e \x01(\x05R\x0fincomingUpdates\x12)\n\x10outgoing_updates\x18\x0f \x01(\x05R\x0foutgoingUpdates\x12/\n\x13incoming_keepalives\x18\x10 \x01(\x05R\x12incomingKeepalives\x12/\n\x13outgoing_keepalives\x18\x11 \x01(\x05R\x12outgoingKeepalives\x12-\n\x12incoming_refreshes\x18\x12 \x01(\x05R\x11incomingRefreshes\x12-\n\x12outgoing_refreshes\x18\x13 \x01(\x05R\x11outgoingRefreshes\x12\x36\n\x17incoming_total_messages\x18\x14 \x01(\x05R\x15incomingTotalMessages\x12\x36\n\x17outgoing_total_messages\x18\x15 \x01(\x05R\x15outgoingTotalMessages\x12.\n\x13\x66sm_est_transitions\x18\x16 \x01(\x05R\x11\x66smEstTransitions\x12.\n\x13\x63onnect_retry_count\x18\x17 \x01(\x05R\x11\x63onnectRetryCount\x12\x16\n\x06peergr\x18\x18 \x01(\x05R\x06peergr\x12%\n\x0estale_pathtime\x18\x19 \x01(\x05R\rstalePathtime\x12&\n\x0forf_entry_count\x18\x1a \x01(\x05R\rorfEntryCount\x12*\n\x11rcvd_msg_elpstime\x18\x1b \x01(\x05R\x0frcvdMsgElpstime\x12&\n\x0froute_refr_sent\x18\x1c \x01(\x05R\rrouteRefrSent\x12&\n\x0froute_refr_rcvd\x18\x1d \x01(\x05R\rrouteRefrRcvd\x12\'\n\x0fincoming_prfxes\x18\x1e \x01(\x05R\x0eincomingPrfxes\x12\'\n\x0foutgoing_prfxes\x18\x1f \x01(\x05R\x0eoutgoingPrfxes\x12<\n\x1aoutgoing_prfxes_advertised\x18  \x01(\x05R\x18outgoingPrfxesAdvertised\x12*\n\x11\x63onnect_retry_int\x18! \x01(\x05R\x0f\x63onnectRetryInt\x12\x38\n\x18outgoing_update_elpstime\x18\" \x01(\x05R\x16outgoingUpdateElpstime\x12\x34\n\x16outgoing_prfxes_denied\x18# \x01(\x05R\x14outgoingPrfxesDenied\x12\x35\n\x17outgoing_prfxes_imp_wdr\x18$ \x01(\x05R\x14outgoingPrfxesImpWdr\x12\x35\n\x17outgoing_prfxes_exp_wdr\x18% \x01(\x05R\x14outgoingPrfxesExpWdr\x12\x35\n\x17incoming_prfxes_imp_wdr\x18& \x01(\x05R\x14incomingPrfxesImpWdr\x12\x35\n\x17incoming_prfxes_exp_wdr\x18\' \x01(\x05R\x14incomingPrfxesExpWdr\x12+\n\x11received_holdtime\x18( \x01(\x05R\x10receivedHoldtime\x12/\n\x13\x66sm_establishedtime\x18) \x01(\x05R\x12\x66smEstablishedtime\x12:\n\x19incoming_updates_elpstime\x18* \x01(\x05R\x17incomingUpdatesElpstime\x12%\n\x0eincoming_opens\x18+ \x01(\x05R\rincomingOpens\x12%\n\x0eoutgoing_opens\x18, \x01(\x05R\routgoingOpens\x12\x1d\n\npeer_index\x18- \x01(\x05R\tpeerIndex\x12\x10\n\x03ttl\x18. \x01(\x05R\x03ttl\x12K\n\noper_state\x18/ \x01(\x0e\x32,.opi_api.network.cloud.v1alpha1.BGPOperStateR\toperState\"\xf0\x01\n\tBGPPeerAf\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x41\n\x04spec\x18\x02 \x01(\x0b\x32-.opi_api.network.cloud.v1alpha1.BGPPeerAfSpecR\x04spec\x12\x45\n\x05state\x18\x03 \x01(\x0b\x32/.opi_api.network.cloud.v1alpha1.BGPPeerAfStatusR\x05state:E\xea\x41\x42\n(opi_api.network.cloud.v1alpha1/bgppeeraf\x12\x16\x62gppeerafs/{bgppeeraf}\"\xdb\x03\n\rBGPPeerAfSpec\x12O\n\nlocal_addr\x18\x01 \x01(\x0b\x32\x30.opi_api.network.opinetcommon.v1alpha1.IPAddressR\tlocalAddr\x12M\n\tpeer_addr\x18\x02 \x01(\x0b\x32\x30.opi_api.network.opinetcommon.v1alpha1.IPAddressR\x08peerAddr\x12\x38\n\x03\x61\x66i\x18\x03 \x01(\x0e\x32&.opi_api.network.cloud.v1alpha1.BGPAfiR\x03\x61\x66i\x12;\n\x04safi\x18\x04 \x01(\x0e\x32\'.opi_api.network.cloud.v1alpha1.BGPSafiR\x04safi\x12!\n\x0cnexthop_self\x18\x05 \x01(\x08R\x0bnexthopSelf\x12!\n\x0c\x64\x65\x66\x61ult_orig\x18\x06 \x01(\x08R\x0b\x64\x65\x66\x61ultOrig\x12\x1d\n\nlocal_port\x18\x07 \x01(\x05R\tlocalPort\x12\x1f\n\x0bremote_port\x18\x08 \x01(\x05R\nremotePort\x12-\n\x13local_addr_scope_id\x18\t \x01(\x05R\x10localAddrScopeId\"\xb9\x02\n\x0f\x42GPPeerAfStatus\x12!\n\x0cupdate_group\x18\x01 \x01(\x05R\x0bupdateGroup\x12-\n\x13local_addr_scope_id\x18\x02 \x01(\x05R\x10localAddrScopeId\x12#\n\rroute_refresh\x18\x03 \x01(\x08R\x0crouteRefresh\x12Y\n\x10\x61\x64\x64_path_cap_neg\x18\x04 \x01(\x0e\x32\x30.opi_api.network.cloud.v1alpha1.BgpAddPathCapNegR\raddPathCapNeg\x12T\n\x10reflector_client\x18\x05 \x01(\x0e\x32).opi_api.network.cloud.v1alpha1.BGPPeerRRR\x0freflectorClient\"\xa1\x01\n\rBGPNLRIPrefix\x12\x45\n\x04spec\x18\x01 \x01(\x0b\x32\x31.opi_api.network.cloud.v1alpha1.BGPNLRIPrefixSpecR\x04spec\x12I\n\x05state\x18\x02 \x01(\x0b\x32\x33.opi_api.network.cloud.v1alpha1.BGPNLRIPrefixStatusR\x05state\"\xd4\x02\n\x11\x42GPNLRIPrefixSpec\x12\x38\n\x03\x61\x66i\x18\x01 \x01(\x0e\x32&.opi_api.network.cloud.v1alpha1.BGPAfiR\x03\x61\x66i\x12;\n\x04safi\x18\x02 \x01(\x0e\x32\'.opi_api.network.cloud.v1alpha1.BGPSafiR\x04safi\x12\x16\n\x06prefix\x18\x03 \x01(\x0cR\x06prefix\x12\x1d\n\nprefix_len\x18\x04 \x01(\x05R\tprefixLen\x12J\n\x0croute_source\x18\x05 \x01(\x0e\x32\'.opi_api.network.cloud.v1alpha1.NLRISrcR\x0brouteSource\x12,\n\x12route_source_index\x18\x06 \x01(\x05R\x10routeSourceIndex\x12\x17\n\x07path_id\x18\x07 \x01(\x05R\x06pathId\"\xde\t\n\x13\x42GPNLRIPrefixStatus\x12\x38\n\x03\x61\x66i\x18\x01 \x01(\x0e\x32&.opi_api.network.cloud.v1alpha1.BGPAfiR\x03\x61\x66i\x12;\n\x04safi\x18\x02 \x01(\x0e\x32\'.opi_api.network.cloud.v1alpha1.BGPSafiR\x04safi\x12\x16\n\x06prefix\x18\x03 \x01(\x0cR\x06prefix\x12\x1d\n\nprefix_len\x18\x04 \x01(\x05R\tprefixLen\x12J\n\x0croute_source\x18\x05 \x01(\x0e\x32\'.opi_api.network.cloud.v1alpha1.NLRISrcR\x0brouteSource\x12,\n\x12route_source_index\x18\x06 \x01(\x05R\x10routeSourceIndex\x12\x17\n\x07path_id\x18\x07 \x01(\x05R\x06pathId\x12\x1d\n\nbest_route\x18\x08 \x01(\x08R\tbestRoute\x12\x1e\n\x0b\x61s_path_str\x18\t \x01(\x0cR\tasPathStr\x12 \n\x0cpath_orig_id\x18\n \x01(\x0cR\npathOrigId\x12\"\n\rnext_hop_addr\x18\x0b \x01(\x0cR\x0bnextHopAddr\x12\x42\n\x07\x61s_size\x18\x0c \x01(\x0e\x32).opi_api.network.cloud.v1alpha1.BgpAsSizeR\x06\x61sSize\x12\x1d\n\necmp_route\x18\r \x01(\x08R\tecmpRoute\x12M\n\tpeer_addr\x18\x0e \x01(\x0b\x32\x30.opi_api.network.opinetcommon.v1alpha1.IPAddressR\x08peerAddr\x12,\n\x12\x66lap_stats_flapcnt\x18\x0f \x01(\x05R\x10\x66lapStatsFlapcnt\x12,\n\x12\x66lap_stats_supprsd\x18\x10 \x01(\x08R\x10\x66lapStatsSupprsd\x12L\n\tis_active\x18\x11 \x01(\x0e\x32/.opi_api.network.cloud.v1alpha1.BgpNlriIsActiveR\x08isActive\x12\x14\n\x05stale\x18\x12 \x01(\x08R\x05stale\x12%\n\x0e\x66lap_starttime\x18\x13 \x01(\x05R\rflapStarttime\x12V\n\x0freason_not_best\x18\x14 \x01(\x0e\x32..opi_api.network.cloud.v1alpha1.BGPRouteReasonR\rreasonNotBest\x12\x19\n\x08\x65xt_comm\x18\x15 \x03(\x0cR\x07\x65xtComm\x12\x12\n\x04\x63omm\x18\x16 \x03(\x0cR\x04\x63omm\x12\x1d\n\nlocal_pref\x18\x17 \x01(\x05R\tlocalPref\x12\x45\n\x06origin\x18\x18 \x01(\x0e\x32-.opi_api.network.cloud.v1alpha1.BGPOriginAttrR\x06origin\x12\x1f\n\x0bmed_present\x18\x19 \x01(\x08R\nmedPresent\x12\x10\n\x03med\x18\x1a \x01(\rR\x03med\x12H\n\tpeer_type\x18\x1b \x01(\x0e\x32+.opi_api.network.cloud.v1alpha1.BGPPeerTypeR\x08peerType\"\x95\x02\n\x13\x42GPNLRIPrefixFilter\x12\x19\n\x08\x65xt_comm\x18\x01 \x01(\x0cR\x07\x65xtComm\x12\x12\n\x04vnid\x18\x02 \x01(\x05R\x04vnid\x12\x1d\n\nroute_type\x18\x03 \x01(\x05R\trouteType\x12K\n\x08next_hop\x18\x04 \x01(\x0b\x32\x30.opi_api.network.opinetcommon.v1alpha1.IPAddressR\x07nextHop\x12O\n\nip_address\x18\x05 \x01(\x0b\x32\x30.opi_api.network.opinetcommon.v1alpha1.IPAddressR\tipAddress\x12\x12\n\x04\x62\x65st\x18\x06 \x01(\x08R\x04\x62\x65st\"\xa0\x01\n\x0c\x42GPAdjRibOut\x12\x44\n\x04spec\x18\x01 \x01(\x0b\x32\x30.opi_api.network.cloud.v1alpha1.BGPAdjRibOutSpecR\x04spec\x12J\n\x06status\x18\x02 \x01(\x0b\x32\x32.opi_api.network.cloud.v1alpha1.BGPAdjRibOutStatusR\x06status\"\x12\n\x10\x42GPAdjRibOutSpec\"\xa0\x04\n\x12\x42GPAdjRibOutStatus\x12M\n\tpeer_addr\x18\x01 \x01(\x0b\x32\x30.opi_api.network.opinetcommon.v1alpha1.IPAddressR\x08peerAddr\x12\x38\n\x03\x61\x66i\x18\x02 \x01(\x0e\x32&.opi_api.network.cloud.v1alpha1.BGPAfiR\x03\x61\x66i\x12;\n\x04safi\x18\x03 \x01(\x0e\x32\'.opi_api.network.cloud.v1alpha1.BGPSafiR\x04safi\x12\x16\n\x06prefix\x18\x04 \x01(\x0cR\x06prefix\x12\x1d\n\nprefix_len\x18\x05 \x01(\x05R\tprefixLen\x12G\n\x05state\x18\x06 \x01(\x0e\x32\x31.opi_api.network.cloud.v1alpha1.BgpAroAdvertStateR\x05state\x12\x42\n\x07\x61s_size\x18\x07 \x01(\x0e\x32).opi_api.network.cloud.v1alpha1.BgpAsSizeR\x06\x61sSize\x12\x1e\n\x0b\x61s_path_str\x18\x08 \x01(\x0cR\tasPathStr\x12\x12\n\x04\x63omm\x18\t \x03(\x0cR\x04\x63omm\x12\x19\n\x08\x65xt_comm\x18\n \x03(\x0cR\x07\x65xtComm\x12\x1f\n\x0bmed_present\x18\x0b \x01(\x08R\nmedPresent\x12\x10\n\x03med\x18\x0c \x01(\rR\x03med*X\n\x06\x42GPAfi\x12\x17\n\x13\x42GP_AFI_UNSPECIFIED\x10\x00\x12\x10\n\x0c\x42GP_AFI_IPV4\x10\x01\x12\x10\n\x0c\x42GP_AFI_IPV6\x10\x02\x12\x11\n\rBGP_AFI_L2VPN\x10\x19*L\n\x07\x42GPSafi\x12\x18\n\x14\x42GP_SAFI_UNSPECIFIED\x10\x00\x12\x14\n\x10\x42GP_SAFI_UNICAST\x10\x01\x12\x11\n\rBGP_SAFI_EVPN\x10\x46*_\n\tBGPPeerRR\x12\x1b\n\x17\x42GP_PEER_RR_UNSPECIFIED\x10\x00\x12\x16\n\x12\x42GP_PEER_RR_CLIENT\x10\x01\x12\x1d\n\x19\x42GP_PEER_RR_MESHED_CLIENT\x10\x02*\x9a\x02\n\x13\x42GPPeerSessionState\x12&\n\"BGP_PEER_SESSION_STATE_UNSPECIFIED\x10\x00\x12\x1f\n\x1b\x42GP_PEER_SESSION_STATE_IDLE\x10\x01\x12\"\n\x1e\x42GP_PEER_SESSION_STATE_CONNECT\x10\x02\x12!\n\x1d\x42GP_PEER_SESSION_STATE_ACTIVE\x10\x03\x12#\n\x1f\x42GP_PEER_SESSION_STATE_OPENSENT\x10\x04\x12&\n\"BGP_PEER_SESSION_STATE_OPENCONFIRM\x10\x05\x12&\n\"BGP_PEER_SESSION_STATE_ESTABLISHED\x10\x06*_\n\tBgpAsSize\x12\x1b\n\x17\x42GP_AS_SIZE_UNSPECIFIED\x10\x00\x12\x19\n\x15\x42GP_AS_SIZE_TWO_OCTET\x10\x01\x12\x1a\n\x16\x42GP_AS_SIZE_FOUR_OCTET\x10\x02*\xd0\x04\n\x0b\x42GPAddrType\x12\x1d\n\x19\x42GP_ADDR_TYPE_UNSPECIFIED\x10\x00\x12\x16\n\x12\x42GP_ADDR_TYPE_IPV4\x10\x01\x12\x16\n\x12\x42GP_ADDR_TYPE_IPV6\x10\x02\x12\x16\n\x12\x42GP_ADDR_TYPE_NSAP\x10\x03\x12\x16\n\x12\x42GP_ADDR_TYPE_HDLC\x10\x04\x12\x19\n\x15\x42GP_ADDR_TYPE_BBN1822\x10\x05\x12\x19\n\x15\x42GP_ADDR_TYPE_IEEE802\x10\x06\x12\x16\n\x12\x42GP_ADDR_TYPE_E163\x10\x07\x12\x16\n\x12\x42GP_ADDR_TYPE_E164\x10\x08\x12\x15\n\x11\x42GP_ADDR_TYPE_F69\x10\t\x12\x16\n\x12\x42GP_ADDR_TYPE_X121\x10\n\x12\x15\n\x11\x42GP_ADDR_TYPE_IPX\x10\x0b\x12\x1b\n\x17\x42GP_ADDR_TYPE_APPLETALK\x10\x0c\x12\x1a\n\x16\x42GP_ADDR_TYPE_DECNETIV\x10\r\x12\x1b\n\x17\x42GP_ADDR_TYPE_BANYANVIN\x10\x0e\x12\x1b\n\x17\x42GP_ADDR_TYPE_E164_NSAP\x10\x0f\x12\x1a\n\x16\x42GP_ADDR_TYPE_IPV4_TNA\x10\x10\x12\x1a\n\x16\x42GP_ADDR_TYPE_IPV6_TNA\x10\x11\x12\x1a\n\x16\x42GP_ADDR_TYPE_NSAP_TNA\x10\x12\x12\x1a\n\x16\x42GP_ADDR_TYPE_VPN_IPV4\x10\x13\x12\x1a\n\x16\x42GP_ADDR_TYPE_VPN_IPV6\x10\x14\x12\x17\n\x13\x42GP_ADDR_TYPE_L2VPN\x10\x19*\xb9\x01\n\x0c\x42GPOperState\x12\x1e\n\x1a\x42GP_OPER_STATE_UNSPECIFIED\x10\x00\x12\x15\n\x11\x42GP_OPER_STATE_UP\x10\x01\x12\x17\n\x13\x42GP_OPER_STATE_DOWN\x10\x02\x12\x1b\n\x17\x42GP_OPER_STATE_GOING_UP\x10\x03\x12\x1d\n\x19\x42GP_OPER_STATE_GOING_DOWN\x10\x04\x12\x1d\n\x19\x42GP_OPER_STATE_ACT_FAILED\x10\x05*\xea\x01\n\x10\x42gpAddPathCapNeg\x12#\n\x1f\x42GP_ADD_PATH_CAP_NEG_SR_DISABLE\x10\x00\x12#\n\x1f\x42GP_ADD_PATH_CAP_NEG_SR_RECEIVE\x10\x01\x12 \n\x1c\x42GP_ADD_PATH_CAP_NEG_SR_SEND\x10\x02\x12 \n\x1c\x42GP_ADD_PATH_CAP_NEG_SR_BOTH\x10\x03\x12#\n\x1f\x42GP_ADD_PATH_CAP_NEG_SR_INHERIT\x10\x04\x12#\n\x1f\x42GP_ADD_PATH_CAP_NEG_SR_UNKNOWN\x10\x05*\xdc\x01\n\x14\x42GPClearRouteOptions\x12\'\n#BGP_CLEAR_ROUTE_OPTIONS_UNSPECIFIED\x10\x00\x12 \n\x1c\x42GP_CLEAR_ROUTE_OPTIONS_HARD\x10\x01\x12&\n\"BGP_CLEAR_ROUTE_OPTIONS_REFRESH_IN\x10\x02\x12\'\n#BGP_CLEAR_ROUTE_OPTIONS_REFRESH_OUT\x10\x03\x12(\n$BGP_CLEAR_ROUTE_OPTIONS_REFRESH_BOTH\x10\x04*[\n\x07NLRISrc\x12\x18\n\x14NLRI_SRC_UNSPECIFIED\x10\x00\x12\x11\n\rNLRI_SRC_PEER\x10\x01\x12\x10\n\x0cNLRI_SRC_AFM\x10\x02\x12\x11\n\rNLRI_SRC_SELF\x10\x03*\x99\x01\n\x0f\x42gpNlriIsActive\x12\"\n\x1e\x42GP_NLRI_IS_ACTIVE_UNSPECIFIED\x10\x00\x12\"\n\x1e\x42GP_NLRI_IS_ACTIVE_NOT_TRACKED\x10\x01\x12\x1f\n\x1b\x42GP_NLRI_IS_ACTIVE_INACTIVE\x10\x02\x12\x1d\n\x19\x42GP_NLRI_IS_ACTIVE_ACTIVE\x10\x03*\x99\x05\n\x0e\x42GPRouteReason\x12#\n\x1f\x42GP_ROUTE_REASON_NOT_CONSIDERED\x10\x00\x12\"\n\x1e\x42GP_ROUTE_REASON_ROUTE_IS_BEST\x10\x01\x12\x1b\n\x17\x42GP_ROUTE_REASON_WEIGHT\x10\x02\x12\x1f\n\x1b\x42GP_ROUTE_REASON_LOCAL_PREF\x10\x03\x12%\n!BGP_ROUTE_REASON_LCL_ORIG_PRFRRED\x10\x04\x12 \n\x1c\x42GP_ROUTE_REASON_AS_PATH_LEN\x10\x05\x12\x1b\n\x17\x42GP_ROUTE_REASON_ORIGIN\x10\x06\x12\x18\n\x14\x42GP_ROUTE_REASON_MED\x10\x07\x12#\n\x1f\x42GP_ROUTE_REASON_LOCAL_ORIG_TIE\x10\x08\x12%\n!BGP_ROUTE_REASON_EBGP_V_IBGP_PEER\x10\t\x12#\n\x1f\x42GP_ROUTE_REASON_ADMIN_DISTANCE\x10\n\x12%\n!BGP_ROUTE_REASON_PATH_TO_NEXT_CST\x10\x0b\x12\"\n\x1e\x42GP_ROUTE_REASON_PREF_EXISTING\x10\x0c\x12\x1f\n\x1b\x42GP_ROUTE_REASON_IDENTIFIER\x10\r\x12 \n\x1c\x42GP_ROUTE_REASON_CLUSTER_LEN\x10\x0e\x12#\n\x1f\x42GP_ROUTE_REASON_PEER_ADDR_TYPE\x10\x0f\x12\x1e\n\x1a\x42GP_ROUTE_REASON_PEER_ADDR\x10\x10\x12\x1e\n\x1a\x42GP_ROUTE_REASON_PEER_PORT\x10\x11\x12\x1c\n\x18\x42GP_ROUTE_REASON_PATH_ID\x10\x12*\x82\x01\n\rBGPOriginAttr\x12\x1f\n\x1b\x42GP_ORIGIN_ATTR_UNSPECIFIED\x10\x00\x12\x17\n\x13\x42GP_ORIGIN_ATTR_IGP\x10\x01\x12\x17\n\x13\x42GP_ORIGIN_ATTR_EGP\x10\x02\x12\x1e\n\x1a\x42GP_ORIGIN_ATTR_INCOMPLETE\x10\x03*t\n\x0b\x42GPPeerType\x12\x1d\n\x19\x42GP_PEER_TYPE_UNSPECIFIED\x10\x00\x12\x16\n\x12\x42GP_PEER_TYPE_NONE\x10\x01\x12\x16\n\x12\x42GP_PEER_TYPE_IBGP\x10\x02\x12\x16\n\x12\x42GP_PEER_TYPE_EBGP\x10\x03*\xd4\x01\n\x11\x42gpAroAdvertState\x12$\n BGP_ARO_ADVERT_STATE_UNSPECIFIED\x10\x00\x12#\n\x1f\x42GP_ARO_ADVERT_STATE_ADVERTISED\x10\x01\x12#\n\x1f\x42GP_ARO_ADVERT_STATE_SUPPRESSED\x10\x02\x12+\n\'BGP_ARO_ADVERT_STATE_PENDING_WITHDRAWAL\x10\x03\x12\"\n\x1e\x42GP_ARO_ADVERT_STATE_WITHDRAWN\x10\x04\x42i\n\x1eopi_api.network.cloud.v1alpha1B\x08\x42GPProtoP\x01Z;github.com/opiproject/opi-api/network/cloud/v1alpha1/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bgp_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036opi_api.network.cloud.v1alpha1B\010BGPProtoP\001Z;github.com/opiproject/opi-api/network/cloud/v1alpha1/gen/go'
  _globals['_BGP']._options = None
  _globals['_BGP']._serialized_options = b'\352A0\n\"opi_api.network.cloud.v1alpha1/bgp\022\nbgps/{bgp}'
  _globals['_BGPPEER']._options = None
  _globals['_BGPPEER']._serialized_options = b'\352A<\n&opi_api.network.cloud.v1alpha1/bgppeer\022\022bgppeers/{bgppeer}'
  _globals['_BGPPEERAF']._options = None
  _globals['_BGPPEERAF']._serialized_options = b'\352AB\n(opi_api.network.cloud.v1alpha1/bgppeeraf\022\026bgppeerafs/{bgppeeraf}'
  _globals['_BGPAFI']._serialized_start=7746
  _globals['_BGPAFI']._serialized_end=7834
  _globals['_BGPSAFI']._serialized_start=7836
  _globals['_BGPSAFI']._serialized_end=7912
  _globals['_BGPPEERRR']._serialized_start=7914
  _globals['_BGPPEERRR']._serialized_end=8009
  _globals['_BGPPEERSESSIONSTATE']._serialized_start=8012
  _globals['_BGPPEERSESSIONSTATE']._serialized_end=8294
  _globals['_BGPASSIZE']._serialized_start=8296
  _globals['_BGPASSIZE']._serialized_end=8391
  _globals['_BGPADDRTYPE']._serialized_start=8394
  _globals['_BGPADDRTYPE']._serialized_end=8986
  _globals['_BGPOPERSTATE']._serialized_start=8989
  _globals['_BGPOPERSTATE']._serialized_end=9174
  _globals['_BGPADDPATHCAPNEG']._serialized_start=9177
  _globals['_BGPADDPATHCAPNEG']._serialized_end=9411
  _globals['_BGPCLEARROUTEOPTIONS']._serialized_start=9414
  _globals['_BGPCLEARROUTEOPTIONS']._serialized_end=9634
  _globals['_NLRISRC']._serialized_start=9636
  _globals['_NLRISRC']._serialized_end=9727
  _globals['_BGPNLRIISACTIVE']._serialized_start=9730
  _globals['_BGPNLRIISACTIVE']._serialized_end=9883
  _globals['_BGPROUTEREASON']._serialized_start=9886
  _globals['_BGPROUTEREASON']._serialized_end=10551
  _globals['_BGPORIGINATTR']._serialized_start=10554
  _globals['_BGPORIGINATTR']._serialized_end=10684
  _globals['_BGPPEERTYPE']._serialized_start=10686
  _globals['_BGPPEERTYPE']._serialized_end=10802
  _globals['_BGPAROADVERTSTATE']._serialized_start=10805
  _globals['_BGPAROADVERTSTATE']._serialized_end=11017
  _globals['_BGP']._serialized_start=93
  _globals['_BGP']._serialized_end=299
  _globals['_BGPSPEC']._serialized_start=302
  _globals['_BGPSPEC']._serialized_end=490
  _globals['_BGPSTATUS']._serialized_start=493
  _globals['_BGPSTATUS']._serialized_end=764
  _globals['_BGPPEER']._serialized_start=767
  _globals['_BGPPEER']._serialized_end=997
  _globals['_BGPPEERSPEC']._serialized_start=1000
  _globals['_BGPPEERSPEC']._serialized_end=1637
  _globals['_BGPPEERSTATUS']._serialized_start=1640
  _globals['_BGPPEERSTATUS']._serialized_end=3941
  _globals['_BGPPEERAF']._serialized_start=3944
  _globals['_BGPPEERAF']._serialized_end=4184
  _globals['_BGPPEERAFSPEC']._serialized_start=4187
  _globals['_BGPPEERAFSPEC']._serialized_end=4662
  _globals['_BGPPEERAFSTATUS']._serialized_start=4665
  _globals['_BGPPEERAFSTATUS']._serialized_end=4978
  _globals['_BGPNLRIPREFIX']._serialized_start=4981
  _globals['_BGPNLRIPREFIX']._serialized_end=5142
  _globals['_BGPNLRIPREFIXSPEC']._serialized_start=5145
  _globals['_BGPNLRIPREFIXSPEC']._serialized_end=5485
  _globals['_BGPNLRIPREFIXSTATUS']._serialized_start=5488
  _globals['_BGPNLRIPREFIXSTATUS']._serialized_end=6734
  _globals['_BGPNLRIPREFIXFILTER']._serialized_start=6737
  _globals['_BGPNLRIPREFIXFILTER']._serialized_end=7014
  _globals['_BGPADJRIBOUT']._serialized_start=7017
  _globals['_BGPADJRIBOUT']._serialized_end=7177
  _globals['_BGPADJRIBOUTSPEC']._serialized_start=7179
  _globals['_BGPADJRIBOUTSPEC']._serialized_end=7197
  _globals['_BGPADJRIBOUTSTATUS']._serialized_start=7200
  _globals['_BGPADJRIBOUTSTATUS']._serialized_end=7744
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: interface.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import networktypes_pb2 as networktypes__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0finterface.proto\x12\x1eopi_api.network.cloud.v1alpha1\x1a\x12networktypes.proto\x1a\x19google/api/resource.proto\"\xf2\x01\n\tInterface\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x41\n\x04spec\x18\x02 \x01(\x0b\x32-.opi_api.network.cloud.v1alpha1.InterfaceSpecR\x04spec\x12G\n\x06status\x18\x03 \x01(\x0b\x32/.opi_api.network.cloud.v1alpha1.InterfaceStatusR\x06status:E\xea\x41\x42\n(opi_api.network.cloud.v1alpha1/interface\x12\x16interfaces/{interface}\"\xee\x04\n\rInterfaceSpec\x12\x12\n\x04ifid\x18\x01 \x01(\x05R\x04ifid\x12K\n\x0c\x61\x64min_status\x18\x02 \x01(\x0e\x32(.opi_api.network.cloud.v1alpha1.IfStatusR\x0b\x61\x64minStatus\x12M\n\x0buplink_spec\x18\x03 \x01(\x0b\x32*.opi_api.network.cloud.v1alpha1.UplinkSpecH\x00R\nuplinkSpec\x12T\n\x0euplink_pc_spec\x18\x04 \x01(\x0b\x32,.opi_api.network.cloud.v1alpha1.UplinkPCSpecH\x00R\x0cuplinkPcSpec\x12H\n\nl3_if_spec\x18\x05 \x01(\x0b\x32(.opi_api.network.cloud.v1alpha1.L3IfSpecH\x00R\x08l3IfSpec\x12Z\n\x10loopback_if_spec\x18\x06 \x01(\x0b\x32..opi_api.network.cloud.v1alpha1.LoopbackIfSpecH\x00R\x0eloopbackIfSpec\x12W\n\x0f\x63ontrol_if_spec\x18\x07 \x01(\x0b\x32-.opi_api.network.cloud.v1alpha1.ControlIfSpecH\x00R\rcontrolIfSpec\x12N\n\x0chost_if_spec\x18\x08 \x01(\x0b\x32*.opi_api.network.cloud.v1alpha1.HostIfSpecH\x00R\nhostIfSpecB\x08\n\x06ifinfo\"U\n\nUplinkSpec\x12\"\n\rport_name_ref\x18\x01 \x01(\tR\x0bportNameRef\x12#\n\rnative_vlanid\x18\x02 \x01(\x05R\x0cnativeVlanid\"c\n\x0cUplinkPCSpec\x12.\n\x13member_ifids_bitmap\x18\x01 \x01(\x04R\x11memberIfidsBitmap\x12#\n\rnative_vlanid\x18\x02 \x01(\x05R\x0cnativeVlanid\"\xfe\x01\n\x08L3IfSpec\x12 \n\x0cvpc_name_ref\x18\x01 \x01(\tR\nvpcNameRef\x12G\n\x06prefix\x18\x02 \x03(\x0b\x32/.opi_api.network.opinetcommon.v1alpha1.IPPrefixR\x06prefix\x12\"\n\rport_name_ref\x18\x03 \x01(\tR\x0bportNameRef\x12\x42\n\x05\x65ncap\x18\x04 \x01(\x0b\x32,.opi_api.network.opinetcommon.v1alpha1.EncapR\x05\x65ncap\x12\x1f\n\x0bmac_address\x18\x05 \x01(\x0cR\nmacAddress\">\n\x0c\x42GPCommunity\x12\x10\n\x03\x61sn\x18\x01 \x01(\x05R\x03\x61sn\x12\x1c\n\tcommunity\x18\x02 \x01(\x05R\tcommunity\"\xa9\x01\n\x0eLoopbackIfSpec\x12G\n\x06prefix\x18\x01 \x01(\x0b\x32/.opi_api.network.opinetcommon.v1alpha1.IPPrefixR\x06prefix\x12N\n\x0b\x63ommunities\x18\x02 \x03(\x0b\x32,.opi_api.network.cloud.v1alpha1.BGPCommunityR\x0b\x63ommunities\"y\n\rControlIfSpec\x12G\n\x06prefix\x18\x01 \x01(\x0b\x32/.opi_api.network.opinetcommon.v1alpha1.IPPrefixR\x06prefix\x12\x1f\n\x0bmac_address\x18\x02 \x01(\x0cR\nmacAddress\"\x93\x01\n\nHostIfSpec\x12\x0e\n\x02vf\x18\x01 \x01(\x08R\x02vf\x12<\n\x1a\x65nable_connection_tracking\x18\x02 \x01(\x08R\x18\x65nableConnectionTracking\x12\x1f\n\x0bmac_address\x18\x03 \x01(\x0cR\nmacAddress\x12\x16\n\x06ifname\x18\x04 \x01(\tR\x06ifname\"R\n\x0eUplinkIfStatus\x12\x1a\n\thw_if_idx\x18\x01 \x01(\x05R\x07hwIfIdx\x12$\n\x0ehw_port_number\x18\x02 \x01(\x05R\x0chwPortNumber\"*\n\x10LoopbackIfStatus\x12\x16\n\x06ifname\x18\x01 \x01(\tR\x06ifname\"\xa9\x01\n\x0cHostIfStatus\x12\x1e\n\x0bhw_if_idxes\x18\x01 \x03(\x0cR\thwIfIdxes\x12\x1f\n\x0bmac_address\x18\x02 \x01(\x0cR\nmacAddress\x12@\n\x06status\x18\x03 \x01(\x0e\x32(.opi_api.network.cloud.v1alpha1.IfStatusR\x06status\x12\x16\n\x06ifname\x18\x04 \x01(\tR\x06ifname\"\x97\x03\n\x0fInterfaceStatus\x12\x19\n\x08if_index\x18\x01 \x01(\rR\x07ifIndex\x12I\n\x0boper_status\x18\x02 \x01(\x0e\x32(.opi_api.network.cloud.v1alpha1.IfStatusR\noperStatus\x12Z\n\x10uplink_if_status\x18\x03 \x01(\x0b\x32..opi_api.network.cloud.v1alpha1.UplinkIfStatusH\x00R\x0euplinkIfStatus\x12`\n\x12loopback_if_status\x18\x04 \x01(\x0b\x32\x30.opi_api.network.cloud.v1alpha1.LoopbackIfStatusH\x00R\x10loopbackIfStatus\x12T\n\x0ehost_if_status\x18\x05 \x01(\x0b\x32,.opi_api.network.cloud.v1alpha1.HostIfStatusH\x00R\x0chostIfStatusB\n\n\x08ifstatus*\x99\x01\n\x06IfType\x12\x17\n\x13IF_TYPE_UNSPECIFIED\x10\x00\x12\x12\n\x0eIF_TYPE_UPLINK\x10\x01\x12\x15\n\x11IF_TYPE_UPLINK_PC\x10\x02\x12\x0e\n\nIF_TYPE_L3\x10\x03\x12\x14\n\x10IF_TYPE_LOOPBACK\x10\x04\x12\x13\n\x0fIF_TYPE_CONTROL\x10\x05\x12\x10\n\x0cIF_TYPE_HOST\x10\x06*K\n\x08IfStatus\x12\x19\n\x15IF_STATUS_UNSPECIFIED\x10\x00\x12\x10\n\x0cIF_STATUS_UP\x10\x01\x12\x12\n\x0eIF_STATUS_DOWN\x10\x02\x42o\n\x1eopi_api.network.cloud.v1alpha1B\x0eInterfaceProtoP\x01Z;github.com/opiproject/opi-api/network/cloud/v1alpha1/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'interface_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036opi_api.network.cloud.v1alpha1B\016InterfaceProtoP\001Z;github.com/opiproject/opi-api/network/cloud/v1alpha1/gen/go'
  _globals['_INTERFACE']._options = None
  _globals['_INTERFACE']._serialized_options = b'\352AB\n(opi_api.network.cloud.v1alpha1/interface\022\026interfaces/{interface}'
  _globals['_IFTYPE']._serialized_start=2633
  _globals['_IFTYPE']._serialized_end=2786
  _globals['_IFSTATUS']._serialized_start=2788
  _globals['_IFSTATUS']._serialized_end=2863
  _globals['_INTERFACE']._serialized_start=99
  _globals['_INTERFACE']._serialized_end=341
  _globals['_INTERFACESPEC']._serialized_start=344
  _globals['_INTERFACESPEC']._serialized_end=966
  _globals['_UPLINKSPEC']._serialized_start=968
  _globals['_UPLINKSPEC']._serialized_end=1053
  _globals['_UPLINKPCSPEC']._serialized_start=1055
  _globals['_UPLINKPCSPEC']._serialized_end=1154
  _globals['_L3IFSPEC']._serialized_start=1157
  _globals['_L3IFSPEC']._serialized_end=1411
  _globals['_BGPCOMMUNITY']._serialized_start=1413
  _globals['_BGPCOMMUNITY']._serialized_end=1475
  _globals['_LOOPBACKIFSPEC']._serialized_start=1478
  _globals['_LOOPBACKIFSPEC']._serialized_end=1647
  _globals['_CONTROLIFSPEC']._serialized_start=1649
  _globals['_CONTROLIFSPEC']._serialized_end=1770
  _globals['_HOSTIFSPEC']._serialized_start=1773
  _globals['_HOSTIFSPEC']._serialized_end=1920
  _globals['_UPLINKIFSTATUS']._serialized_start=1922
  _globals['_UPLINKIFSTATUS']._serialized_end=2004
  _globals['_LOOPBACKIFSTATUS']._serialized_start=2006
  _globals['_LOOPBACKIFSTATUS']._serialized_end=2048
  _globals['_HOSTIFSTATUS']._serialized_start=2051
  _globals['_HOSTIFSTATUS']._serialized_end=2220
  _globals['_INTERFACESTATUS']._serialized_start=2223
  _globals['_INTERFACESTATUS']._serialized_end=2630
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['pydpu', 'pydpu.dpuredfish', 'pydpu.proto', 'pydpu.proto.v1']

package_data = \
{'': ['*']}

install_requires = \
['Click>=8.1,<9.0',
 'google-api-core>=2.11.0,<3.0.0',
 'google>=3.0.0,<4.0.0',
 'grpcio>=1.51.1,<2.0.0',
 'redfish>=3.2.1,<4.0.0']

entry_points = \
{'console_scripts': ['dpu = pydpu.cli:main']}

setup_kwargs = {
    'name': 'pydpu',
    'version': '0.2.1',
    'description': 'Python library and cli to communicate with DPUs and IPUs',
    'long_description': '# pydpu\n\n[![License](https://img.shields.io/github/license/opiproject/pydpu?style=flat&color=blue&label=License)](https://github.com/opiproject/pydpu/blob/main/LICENSE)\n[![Pulls](https://img.shields.io/docker/pulls/opiproject/pydpu.svg?logo=docker&style=flat&label=Pulls)](https://hub.docker.com/r/opiproject/pydpu)\n[![PyPI](https://img.shields.io/pypi/v/pydpu)](https://pypi.org/project/pydpu/)\n[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg?style=flat)](https://github.com/psf/black)\n[![codecov](https://codecov.io/gh/opiproject/pydpu/branch/main/graph/badge.svg)](https://codecov.io/gh/opiproject/pydpu)\n[![Linters](https://github.com/opiproject/pydpu/actions/workflows/linters.yml/badge.svg)](https://github.com/opiproject/pydpu/actions/workflows/linters.yml)\n[![CodeQL](https://github.com/opiproject/pydpu/actions/workflows/codeql.yml/badge.svg)](https://github.com/opiproject/pydpu/actions/workflows/codeql.yml)\n[![OpenSSF Scorecard](https://api.securityscorecards.dev/projects/github.com/opiproject/pydpu/badge)](https://securityscorecards.dev/viewer/?platform=github.com&org=opiproject&repo=pydpu)\n[![Docker](https://github.com/opiproject/pydpu/actions/workflows/docker.yaml/badge.svg)](https://github.com/opiproject/pydpu/actions/workflows/docker.yaml)\n[![Tests](https://github.com/opiproject/pydpu/actions/workflows/python.yaml/badge.svg)](https://github.com/opiproject/pydpu/actions/workflows/python.yaml)\n[![GitHub stars](https://img.shields.io/github/stars/opiproject/pydpu.svg?style=flat-square&label=github%20stars)](https://github.com/opiproject/pydpu)\n[![GitHub Contributors](https://img.shields.io/github/contributors/opiproject/pydpu.svg?style=flat-square)](https://github.com/opiproject/pydpu/graphs/contributors)\n\nPython library and cli to communicate with DPUs and IPUs\n\n## I Want To Contribute\n\nThis project welcomes contributions and suggestions.  We are happy to have the Community involved via submission of **Issues and Pull Requests** (with substantive content or even just fixes). We are hoping for the documents, test framework, etc. to become a community process with active engagement.  PRs can be reviewed by by any number of people, and a maintainer may accept.\n\nSee [CONTRIBUTING](https://github.com/opiproject/opi/blob/main/CONTRIBUTING.md) and [GitHub Basic Process](https://github.com/opiproject/opi/blob/main/doc-github-rules.md) for more details.\n\n## Installation\n\nThere are several ways of running this CLI.\n\n### Docker\n\n```sh\ndocker pull opiproject/pydpu:<version>\n```\n\nYou can specify a version like `0.1.1` or use `latest` to get the most up-to-date version.\n\nRun latest version of the CLI in a container:\n\n```sh\ndocker run -it --rm --network=host opiproject/pydpu:latest --help\n```\n\nReplace `--help` with any `pydpu` command, without `pydpu` itself.\n\n### PyPI\n\n```sh\npip install pydpu\n```\n\n## Usage\n\n### Version\n\nTo get version, run:\n\n```sh\n$ pydpu --version\ndpu, version 0.1.1\n```\n\n### Redfish\n\nTo communicate over redfish, run:\n\n```sh\npydpu --address=10.10.10.10 redfish --username root --password 0penBmc test\n```\n\n### Inventory\n\nTo get inventory, run:\n\n```sh\npydpu --address=localhost:50151 inventory get\n```\n\n### Ipsec\n\nTo create a tunnel, run:\n\n```sh\npydpu --address=localhost:50151 ipsec create-tunnel\n```\n\nTo get statistics, run:\n\n```sh\npydpu --address=localhost:50151 ipsec stats\n```\n\n### Storage\n\nTo create a subsystem, run:\n\n```sh\npydpu --address=localhost:50151 storage subsystem\n```\n\nTo create a controller, run:\n\n```sh\npydpu --address=localhost:50151 storage controller\n```\n\nTo create a namespace, run:\n\n```sh\npydpu --address=localhost:50151 storage namespace\n```\n\n### Evpn\n\nTo create a logical bridge, run:\n\n```sh\npydpu --address=localhost:50151 evpn bridge\n```\n\nTo create a bridge port, run:\n\n```sh\npydpu --address=localhost:50151 evpn port\n```\n\nTo create a vrf, run:\n\n```sh\npydpu --address=localhost:50151 evpn vrf\n```\n\nTo create a svi, run:\n\n```sh\npydpu --address=localhost:50151 evpn svi\n```\n\n## Packaging\n\nThis project uses [poetry](https://python-poetry.org/) to manage dependencies, build, etc.\n\n## Releasing new versions\n\n```sh\n# Make sure you have dev dependencies installed\n$ poetry install --group dev\n# Use bump2version to update version strings and create a new tag\n$ bump2version <patch|minor|major>\n# Push new tag\n$ git push --tags\n# Create GitHub release\n$ gh release create v$(poetry version -s) --generate-notes\n```\n',
    'author': 'OPI Dev',
    'author_email': 'opi-dev@lists.opiproject.org',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8.1,<4.0',
}


setup(**setup_kwargs)
